@@ -14,7 +14,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.commons.dbcp2;
 
 import java.sql.CallableStatement;
@@ -22,6 +21,7 @@ import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.SQLException;
 import java.util.NoSuchElementException;
+import java.util.Objects;
 
 import org.apache.commons.pool2.KeyedObjectPool;
 import org.apache.commons.pool2.KeyedPooledObjectFactory;
@@ -63,7 +63,7 @@ public class PoolingConnection extends DelegatingConnection<Connection>
     }
 
     /** Pool of {@link PreparedStatement}s. and {@link CallableStatement}s */
-    private KeyedObjectPool<PStmtKey, DelegatingPreparedStatement> pstmtPool;
+    private KeyedObjectPool<PStmtKey, DelegatingPreparedStatement> pStmtPool;
 
     private boolean clearStatementPoolOnReturn;
 
@@ -87,7 +87,7 @@ public class PoolingConnection extends DelegatingConnection<Connection>
      */
     @Override
     public void activateObject(final PStmtKey key, final PooledObject<DelegatingPreparedStatement> pooledObject)
-            throws Exception {
+            throws SQLException {
         pooledObject.getObject().activate();
     }
 
@@ -98,11 +98,11 @@ public class PoolingConnection extends DelegatingConnection<Connection>
     @Override
     public synchronized void close() throws SQLException {
         try {
-            if (null != pstmtPool) {
-                final KeyedObjectPool<PStmtKey, DelegatingPreparedStatement> oldpool = pstmtPool;
-                pstmtPool = null;
+            if (null != pStmtPool) {
+                final KeyedObjectPool<PStmtKey, DelegatingPreparedStatement> oldPool = pStmtPool;
+                pStmtPool = null;
                 try {
-                    oldpool.close();
+                    oldPool.close();
                 } catch (final RuntimeException e) {
                     throw e;
                 } catch (final Exception e) {
@@ -121,14 +121,14 @@ public class PoolingConnection extends DelegatingConnection<Connection>
     /**
      * Notification from {@link PoolableConnection} that we returned to the pool.
      *
-     * @throws SQLException when <code>clearStatementPoolOnReturn</code> is true and the statement pool could not be
+     * @throws SQLException when {@code clearStatementPoolOnReturn} is true and the statement pool could not be
      *                      cleared
      * @since 2.8.0
      */
     public void connectionReturnedToPool() throws SQLException {
-        if (pstmtPool != null && clearStatementPoolOnReturn) {
+        if (pStmtPool != null && clearStatementPoolOnReturn) {
             try {
-                pstmtPool.clear();
+                pStmtPool.clear();
             } catch (final Exception e) {
                 throw new SQLException("Error clearing statement pool", e);
             }
@@ -154,7 +154,7 @@ public class PoolingConnection extends DelegatingConnection<Connection>
      *            the SQL string used to define the statement
      * @param autoGeneratedKeys
      *            A flag indicating whether auto-generated keys should be returned; one of
-     *            <code>Statement.RETURN_GENERATED_KEYS</code> or <code>Statement.NO_GENERATED_KEYS</code>.
+     *            {@code Statement.RETURN_GENERATED_KEYS} or {@code Statement.NO_GENERATED_KEYS}.
      *
      * @return the PStmtKey created for the given arguments.
      */
@@ -293,43 +293,39 @@ public class PoolingConnection extends DelegatingConnection<Connection>
      */
     @Override
     public void destroyObject(final PStmtKey key, final PooledObject<DelegatingPreparedStatement> pooledObject)
-            throws Exception {
+            throws SQLException {
         pooledObject.getObject().getInnermostDelegate().close();
     }
 
     private String getCatalogOrNull() {
-        String catalog = null;
         try {
-            catalog = getCatalog();
-        } catch (final SQLException e) {
-            // Ignored
+            return getCatalog();
+        } catch (final SQLException ignored) {
+            return null;
         }
-        return catalog;
     }
 
     private String getSchemaOrNull() {
-        String schema = null;
         try {
-            schema = getSchema();
-        } catch (final SQLException e) {
-            // Ignored
+            return getSchema();
+        } catch (final SQLException ignored) {
+            return null;
         }
-        return schema;
     }
 
     /**
-     * Returns the prepared statement pool we're using.
+     * Gets the prepared statement pool.
      *
      * @return statement pool
      * @since 2.8.0
      */
     public KeyedObjectPool<PStmtKey, DelegatingPreparedStatement> getStatementPool() {
-        return pstmtPool;
+        return pStmtPool;
     }
 
     /**
      * {@link KeyedPooledObjectFactory} method for creating {@link PoolablePreparedStatement}s or
-     * {@link PoolableCallableStatement}s. The <code>stmtType</code> field in the key determines whether a
+     * {@link PoolableCallableStatement}s. The {@code stmtType} field in the key determines whether a
      * PoolablePreparedStatement or PoolableCallableStatement is created.
      *
      * @param key
@@ -338,18 +334,18 @@ public class PoolingConnection extends DelegatingConnection<Connection>
      */
     @SuppressWarnings("resource")
     @Override
-    public PooledObject<DelegatingPreparedStatement> makeObject(final PStmtKey key) throws Exception {
+    public PooledObject<DelegatingPreparedStatement> makeObject(final PStmtKey key) throws SQLException {
         if (null == key) {
             throw new IllegalArgumentException("Prepared statement key is null or invalid.");
         }
         if (key.getStmtType() == StatementType.PREPARED_STATEMENT) {
             final PreparedStatement statement = (PreparedStatement) key.createStatement(getDelegate());
             @SuppressWarnings({"rawtypes", "unchecked" }) // Unable to find way to avoid this
-            final PoolablePreparedStatement pps = new PoolablePreparedStatement(statement, key, pstmtPool, this);
+            final PoolablePreparedStatement pps = new PoolablePreparedStatement(statement, key, pStmtPool, this);
             return new DefaultPooledObject<>(pps);
         }
         final CallableStatement statement = (CallableStatement) key.createStatement(getDelegate());
-        final PoolableCallableStatement pcs = new PoolableCallableStatement(statement, key, pstmtPool, this);
+        final PoolableCallableStatement pcs = new PoolableCallableStatement(statement, key, pStmtPool, this);
         return new DefaultPooledObject<>(pcs);
     }
 
@@ -375,7 +371,7 @@ public class PoolingConnection extends DelegatingConnection<Connection>
      */
     @Override
     public void passivateObject(final PStmtKey key, final PooledObject<DelegatingPreparedStatement> pooledObject)
-            throws Exception {
+            throws SQLException {
         @SuppressWarnings("resource")
         final DelegatingPreparedStatement dps = pooledObject.getObject();
         dps.clearParameters();
@@ -460,11 +456,11 @@ public class PoolingConnection extends DelegatingConnection<Connection>
      *             Wraps an underlying exception.
      */
     private PreparedStatement prepareStatement(final PStmtKey key) throws SQLException {
-        if (null == pstmtPool) {
+        if (null == pStmtPool) {
             throw new SQLException("Statement pool is null - closed or invalid PoolingConnection.");
         }
         try {
-            return pstmtPool.borrowObject(key);
+            return pStmtPool.borrowObject(key);
         } catch (final NoSuchElementException e) {
             throw new SQLException("MaxOpenPreparedStatements limit reached", e);
         } catch (final RuntimeException e) {
@@ -495,7 +491,7 @@ public class PoolingConnection extends DelegatingConnection<Connection>
      *            the SQL string used to define the PreparedStatement
      * @param autoGeneratedKeys
      *            A flag indicating whether auto-generated keys should be returned; one of
-     *            <code>Statement.RETURN_GENERATED_KEYS</code> or <code>Statement.NO_GENERATED_KEYS</code>.
+     *            {@code Statement.RETURN_GENERATED_KEYS} or {@code Statement.NO_GENERATED_KEYS}.
      * @return a {@link PoolablePreparedStatement}
      * @throws SQLException
      *             Wraps an underlying exception.
@@ -597,19 +593,16 @@ public class PoolingConnection extends DelegatingConnection<Connection>
      *            the prepared statement pool.
      */
     public void setStatementPool(final KeyedObjectPool<PStmtKey, DelegatingPreparedStatement> pool) {
-        pstmtPool = pool;
+        pStmtPool = pool;
     }
 
     @Override
     public synchronized String toString() {
-        if (pstmtPool != null) {
-            return "PoolingConnection: " + pstmtPool.toString();
-        }
-        return "PoolingConnection: null";
+        return "PoolingConnection: " + Objects.toString(pStmtPool);
     }
 
     /**
-     * {@link KeyedPooledObjectFactory} method for validating pooled statements. Currently always returns true.
+     * {@link KeyedPooledObjectFactory} method for validating pooled statements. Currently, always returns true.
      *
      * @param key
      *            ignored
