@@ -32,6 +32,7 @@ import java.lang.management.ManagementFactory;
 import java.lang.management.ThreadMXBean;
 import java.sql.Connection;
 import java.sql.SQLException;
+import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Properties;
@@ -83,7 +84,7 @@ public class TestBasicDataSource extends TestConnectionPool {
         ds.setDriverClassName("org.apache.commons.dbcp2.TesterDriver");
         ds.setUrl("jdbc:apache:commons:testdriver");
         ds.setMaxTotal(getMaxTotal());
-        ds.setMaxWaitMillis(getMaxWaitMillis());
+        ds.setMaxWait(getMaxWaitDuration());
         ds.setDefaultAutoCommit(Boolean.TRUE);
         ds.setDefaultReadOnly(Boolean.FALSE);
         ds.setDefaultTransactionIsolation(Connection.TRANSACTION_READ_COMMITTED);
@@ -158,12 +159,7 @@ public class TestBasicDataSource extends TestConnectionPool {
         assertTrue(rawActiveConnection.isClosed());
 
         // Verify SQLException on getConnection after close
-        try {
-            getConnection();
-            fail("Expecting SQLException");
-        } catch (final SQLException ex) {
-            // Expected
-        }
+        assertThrows(SQLException.class, () -> getConnection());
 
         // Redundant close is OK
         ds.close();
@@ -177,22 +173,22 @@ public class TestBasicDataSource extends TestConnectionPool {
         ds.setInitialSize(8);
 
         // Launch a request to trigger pool initialization
-        final TestThread testThread = new TestThread(1,0);
+        final TestThread testThread = new TestThread(1, 0);
         final Thread t = new Thread(testThread);
         t.start();
 
         // Get another connection (should wait for pool init)
         Thread.sleep(100); // Make sure t gets into init first
-        ds.getConnection();
+        try (Connection conn = ds.getConnection()) {
 
-        // Pool should have at least 6 idle connections now
-        // Use underlying pool getNumIdle to avoid waiting for ds lock
-        assertTrue(ds.getConnectionPool().getNumIdle() > 5);
-
-        // Make sure t completes successfully
-        t.join();
-        assertFalse(testThread.failed());
+            // Pool should have at least 6 idle connections now
+            // Use underlying pool getNumIdle to avoid waiting for ds lock
+            assertTrue(ds.getConnectionPool().getNumIdle() > 5);
 
+            // Make sure t completes successfully
+            t.join();
+            assertFalse(testThread.failed());
+        }
         ds.close();
     }
 
@@ -208,7 +204,7 @@ public class TestBasicDataSource extends TestConnectionPool {
         ds.setValidationQuery("SELECT DUMMY FROM DUAL");
         ds.setMaxTotal(8);
         ds.setLifo(true);
-        ds.setMaxWaitMillis(-1);
+        ds.setMaxWait(Duration.ofMillis(-1));
 
         // Threads just borrow and return - validation will trigger close check
         final TestThread testThread1 = new TestThread(1000,0);
@@ -238,22 +234,9 @@ public class TestBasicDataSource extends TestConnectionPool {
      * Verify that ConnectionFactory interface in BasicDataSource.createConnectionFactory().
      */
     @Test
-    public void testCreateConnectionFactory() throws Exception {
-
-        /* not set ConnectionFactoryClassName */
-    	Properties properties = new Properties();
-        properties.put("initialSize", "1");
-        properties.put("driverClassName", "org.apache.commons.dbcp2.TesterDriver");
-        properties.put("url", "jdbc:apache:commons:testdriver");
-        properties.put("username", "foo");
-        properties.put("password", "bar");
-        BasicDataSource ds = BasicDataSourceFactory.createDataSource(properties);
-        Connection conn = ds.getConnection();
-        assertNotNull(conn);
-        conn.close();
-        ds.close();
-
-        /* set ConnectionFactoryClassName */
+    public void testCreateConnectionFactoryWithConnectionFactoryClassName() throws Exception {
+        Properties properties = new Properties();
+        // set ConnectionFactoryClassName
         properties = new Properties();
         properties.put("initialSize", "1");
         properties.put("driverClassName", "org.apache.commons.dbcp2.TesterDriver");
@@ -261,12 +244,31 @@ public class TestBasicDataSource extends TestConnectionPool {
         properties.put("username", "foo");
         properties.put("password", "bar");
         properties.put("connectionFactoryClassName", "org.apache.commons.dbcp2.TesterConnectionFactory");
-        ds = BasicDataSourceFactory.createDataSource(properties);
-        conn = ds.getConnection();
-        assertNotNull(conn);
+        try (BasicDataSource ds = BasicDataSourceFactory.createDataSource(properties)) {
+            try (Connection conn = ds.getConnection()) {
+                assertNotNull(conn);
+            }
+        }
+    }
 
-        conn.close();
-        ds.close();
+    /**
+     * JIRA: DBCP-547
+     * Verify that ConnectionFactory interface in BasicDataSource.createConnectionFactory().
+     */
+    @Test
+    public void testCreateConnectionFactoryWithoutConnectionFactoryClassName() throws Exception {
+        // not set ConnectionFactoryClassName
+        final Properties properties = new Properties();
+        properties.put("initialSize", "1");
+        properties.put("driverClassName", "org.apache.commons.dbcp2.TesterDriver");
+        properties.put("url", "jdbc:apache:commons:testdriver");
+        properties.put("username", "foo");
+        properties.put("password", "bar");
+        try (BasicDataSource ds = BasicDataSourceFactory.createDataSource(properties)) {
+            try (Connection conn = ds.getConnection()) {
+                assertNotNull(conn);
+            }
+        }
     }
 
     /**
@@ -287,7 +289,7 @@ public class TestBasicDataSource extends TestConnectionPool {
         // Make password incorrect, so createDataSource will throw
         ds.setPassword("wrong");
         // Set timeBetweenEvictionRuns > 0, so evictor will be created
-        ds.setTimeBetweenEvictionRunsMillis(100);
+        ds.setDurationBetweenEvictionRuns(Duration.ofMillis(100));
         // Set min idle > 0, so evictor will try to make connection as many as idle count
         ds.setMinIdle(2);
 
@@ -296,11 +298,10 @@ public class TestBasicDataSource extends TestConnectionPool {
             TesterConnRequestCountDriver.initConnRequestCount();
 
             // user request 10 times
-            for (int i=0; i<10; i++) {
+            for (int i = 0; i < 10; i++) {
                 try {
                     @SuppressWarnings("unused")
-                    final
-                    DataSource ds2 = ds.createDataSource();
+                    final DataSource ds2 = ds.createDataSource();
                 } catch (final SQLException e) {
                     // Ignore
                 }
@@ -329,14 +330,14 @@ public class TestBasicDataSource extends TestConnectionPool {
         ds.setDriverClassName("org.apache.commons.dbcp2.TesterDriver");
         ds.setUrl("jdbc:apache:commons:testdriver");
         ds.setMaxTotal(getMaxTotal());
-        ds.setMaxWaitMillis(getMaxWaitMillis());
+        ds.setMaxWait(getMaxWaitDuration());
         ds.setDefaultAutoCommit(Boolean.TRUE);
         ds.setDefaultReadOnly(Boolean.FALSE);
         ds.setDefaultTransactionIsolation(Connection.TRANSACTION_READ_COMMITTED);
         ds.setDefaultCatalog(CATALOG);
         ds.setUsername("userName");
         // Set timeBetweenEvictionRuns > 0, so evictor is created
-        ds.setTimeBetweenEvictionRunsMillis(100);
+        ds.setDurationBetweenEvictionRuns(Duration.ofMillis(100));
         // Make password incorrect, so createDataSource will throw
         ds.setPassword("wrong");
         ds.setValidationQuery("SELECT DUMMY FROM DUAL");
@@ -376,6 +377,53 @@ public class TestBasicDataSource extends TestConnectionPool {
         }
     }
 
+    @Test
+    public void testDeprecatedAccessors() throws SQLException {
+        try (BasicDataSource bds = new BasicDataSource()) {
+            int i = 0;
+            //
+            i++;
+            bds.setDefaultQueryTimeout(i);
+            assertEquals(i, bds.getDefaultQueryTimeout());
+            assertEquals(Duration.ofSeconds(i), bds.getDefaultQueryTimeoutDuration());
+            //
+            i++;
+            bds.setMaxConnLifetimeMillis(i);
+            assertEquals(i, bds.getMaxConnLifetimeMillis());
+            assertEquals(Duration.ofMillis(i), bds.getMaxConnDuration());
+            //
+            i++;
+            bds.setMaxWaitMillis(i);
+            assertEquals(i, bds.getMaxWaitMillis());
+            assertEquals(Duration.ofMillis(i), bds.getMaxWaitDuration());
+            //
+            i++;
+            bds.setMinEvictableIdleTimeMillis(i);
+            assertEquals(i, bds.getMinEvictableIdleTimeMillis());
+            assertEquals(Duration.ofMillis(i), bds.getMinEvictableIdleDuration());
+            //
+            i++;
+            bds.setRemoveAbandonedTimeout(i);
+            assertEquals(i, bds.getRemoveAbandonedTimeout());
+            assertEquals(Duration.ofSeconds(i), bds.getRemoveAbandonedTimeoutDuration());
+            //
+            i++;
+            bds.setSoftMinEvictableIdleTimeMillis(i);
+            assertEquals(i, bds.getSoftMinEvictableIdleTimeMillis());
+            assertEquals(Duration.ofMillis(i), bds.getSoftMinEvictableIdleDuration());
+            //
+            i++;
+            bds.setTimeBetweenEvictionRunsMillis(i);
+            assertEquals(i, bds.getTimeBetweenEvictionRunsMillis());
+            assertEquals(Duration.ofMillis(i), bds.getDurationBetweenEvictionRuns());
+            //
+            i++;
+            bds.setValidationQueryTimeout(1);
+            assertEquals(1, bds.getValidationQueryTimeout());
+            assertEquals(Duration.ofSeconds(1), bds.getValidationQueryTimeoutDuration());
+        }
+    }
+
     /**
      * JIRA: DBCP-437
      * Verify that BasicDataSource sets disconnect codes properties.
@@ -387,13 +435,13 @@ public class TestBasicDataSource extends TestConnectionPool {
         disconnectionSqlCodes.add("XXX");
         ds.setDisconnectionSqlCodes(disconnectionSqlCodes);
         ds.setFastFailValidation(true);
-        ds.getConnection();  // Triggers initialization - pcf creation
-        // Make sure factory got the properties
-        final PoolableConnectionFactory pcf =
-                (PoolableConnectionFactory) ds.getConnectionPool().getFactory();
-        assertTrue(pcf.isFastFailValidation());
-        assertTrue(pcf.getDisconnectionSqlCodes().contains("XXX"));
-        assertEquals(1, pcf.getDisconnectionSqlCodes().size());
+        try (Connection conn = ds.getConnection()) { // Triggers initialization - pcf creation
+            // Make sure factory got the properties
+            final PoolableConnectionFactory pcf = (PoolableConnectionFactory) ds.getConnectionPool().getFactory();
+            assertTrue(pcf.isFastFailValidation());
+            assertTrue(pcf.getDisconnectionSqlCodes().contains("XXX"));
+            assertEquals(1, pcf.getDisconnectionSqlCodes().size());
+        }
     }
 
     /**
@@ -402,11 +450,12 @@ public class TestBasicDataSource extends TestConnectionPool {
      */
     @Test
     public void testDriverClassLoader() throws Exception {
-        getConnection();
-        final ClassLoader cl = ds.getDriverClassLoader();
-        assertNotNull(cl);
-        assertTrue(cl instanceof TesterClassLoader);
-        assertTrue(((TesterClassLoader) cl).didLoad(ds.getDriverClassName()));
+        try (Connection conn = getConnection()) {
+            final ClassLoader cl = ds.getDriverClassLoader();
+            assertNotNull(cl);
+            assertTrue(cl instanceof TesterClassLoader);
+            assertTrue(((TesterClassLoader) cl).didLoad(ds.getDriverClassName()));
+        }
     }
 
     @Test
@@ -441,24 +490,23 @@ public class TestBasicDataSource extends TestConnectionPool {
         ds.setMaxTotal(10);
         ds.setMinIdle(5);
         ds.setNumTestsPerEvictionRun(3);
-        ds.setMinEvictableIdleTimeMillis(100);
-        ds.setTimeBetweenEvictionRunsMillis(delay);
+        ds.setMinEvictableIdle(Duration.ofMillis(100));
+        ds.setDurationBetweenEvictionRuns(Duration.ofMillis(delay));
         ds.setPoolPreparedStatements(true);
 
-        final Connection conn = ds.getConnection();
-        conn.close();
+        try (Connection conn = ds.getConnection()) {
+            // empty
+        }
 
         final ThreadMXBean threadBean = ManagementFactory.getThreadMXBean();
-        while (Stream.of(threadBean.getThreadInfo(threadBean.getAllThreadIds()))
-                .anyMatch(t -> t.getThreadName().equals("commons-pool-evictor-thread"))) {
+        while (Stream.of(threadBean.getThreadInfo(threadBean.getAllThreadIds())).anyMatch(t -> t.getThreadName().equals("commons-pool-evictor-thread"))) {
             if (ds.getNumIdle() <= ds.getMinIdle()) {
                 break;
             }
             Thread.sleep(delay);
         }
         if (ds.getNumIdle() > ds.getMinIdle()) {
-            fail("EvictionTimer thread was destroyed with numIdle=" + ds.getNumIdle() + "(expected: less or equal than "
-                    + ds.getMinIdle() + ")");
+            fail("EvictionTimer thread was destroyed with numIdle=" + ds.getNumIdle() + "(expected: less or equal than " + ds.getMinIdle() + ")");
         }
     }
 
@@ -468,9 +516,9 @@ public class TestBasicDataSource extends TestConnectionPool {
         ds.setMaxIdle(20);
         ds.setInitialSize(10);
 
-        final Connection conn = getConnection();
-        assertNotNull(conn);
-        conn.close();
+        try (Connection conn = getConnection()) {
+            assertNotNull(conn);
+        }
 
         assertEquals(0, ds.getNumActive());
         assertEquals(10, ds.getNumIdle());
@@ -515,28 +563,16 @@ public class TestBasicDataSource extends TestConnectionPool {
 
     @Test
     public void testInvalidConnectionInitSql() {
-        try {
-            ds.setConnectionInitSqls(Arrays.asList("SELECT 1", "invalid"));
-            try (Connection c = ds.getConnection()) {}
-            fail("expected SQLException");
-        }
-        catch (final SQLException e) {
-            if (!e.toString().contains("invalid")) {
-                fail("expected detailed error message");
-            }
-        }
+        ds.setConnectionInitSqls(Arrays.asList("SELECT 1", "invalid"));
+        final SQLException e = assertThrows(SQLException.class, ds::getConnection);
+        assertTrue(e.toString().contains("invalid"));
     }
 
     @Test
     public void testInvalidValidationQuery() {
         ds.setValidationQuery("invalid");
-        try (Connection c = ds.getConnection()) {
-            fail("expected SQLException");
-        } catch (final SQLException e) {
-            if (!e.toString().contains("invalid")) {
-                fail("expected detailed error message");
-            }
-        }
+        final SQLException e = assertThrows(SQLException.class, ds::getConnection);
+        assertTrue(e.toString().contains("invalid"));
     }
 
     // Bugzilla Bug 28251:  Returning dead database connections to BasicDataSource
@@ -549,14 +585,10 @@ public class TestBasicDataSource extends TestConnectionPool {
         assertEquals(1, ds.getNumActive());
 
         // set an IO failure causing the isClosed method to fail
-        final TesterConnection tconn = (TesterConnection) ((DelegatingConnection<?>)conn).getInnermostDelegate();
+        final TesterConnection tconn = (TesterConnection) ((DelegatingConnection<?>) conn).getInnermostDelegate();
         tconn.setFailure(new IOException("network error"));
 
-        try {
-            conn.close();
-            fail("Expected SQLException");
-        }
-        catch(final SQLException ex) { }
+        assertThrows(SQLException.class, () -> conn.close());
 
         assertEquals(0, ds.getNumActive());
     }
@@ -582,11 +614,33 @@ public class TestBasicDataSource extends TestConnectionPool {
         for (final ObjectName result : results) {
             mbs.unregisterMBean(result);
         }
-        ds.setJmxName(null);  // Should disable JMX for both connection and statement pools
+        ds.setJmxName(null); // Should disable JMX for both connection and statement pools
         ds.setPoolPreparedStatements(true);
-        ds.getConnection();  // Trigger initialization
-        // Nothing should be registered
-        assertEquals(0, mbs.queryNames(commons, null).size());
+        try (Connection conn = ds.getConnection()) { // Trigger initialization
+            // Nothing should be registered
+            assertEquals(0, mbs.queryNames(commons, null).size());
+        }
+    }
+
+    /**
+     * Test disabling MBean registration for Connection objects.
+     * JIRA: DBCP-585
+     */
+    @Test
+    public void testConnectionMBeansDisabled() throws Exception {
+        final MBeanServer mbs = ManagementFactory.getPlatformMBeanServer();
+        // Unregister leftovers from other tests (TODO: worry about concurrent test execution)
+        final ObjectName commons = new ObjectName("org.apache.commons.*:*");
+        final Set<ObjectName> results = mbs.queryNames(commons, null);
+        for (final ObjectName result : results) {
+            mbs.unregisterMBean(result);
+        }
+        ds.setRegisterConnectionMBean(false); // Should disable Connection MBean registration
+        try (Connection conn = ds.getConnection()) { // Trigger initialization
+            // No Connection MBeans shall be registered
+            final ObjectName connections = new ObjectName("org.apache.commons.*:connection=*,*");
+            assertEquals(0, mbs.queryNames(connections, null).size());
+        }
     }
 
     /**
@@ -621,16 +675,12 @@ public class TestBasicDataSource extends TestConnectionPool {
     public void testManualConnectionEvict() throws Exception {
         ds.setMinIdle(0);
         ds.setMaxIdle(4);
-        ds.setMinEvictableIdleTimeMillis(10);
+        ds.setMinEvictableIdle(Duration.ofMillis(10));
         ds.setNumTestsPerEvictionRun(2);
 
-        final Connection ds2 = ds.createDataSource().getConnection();
-        final Connection ds3 = ds.createDataSource().getConnection();
-
-        assertEquals(0, ds.getNumIdle());
-
-        ds2.close();
-        ds3.close();
+        try (Connection ds2 = ds.createDataSource().getConnection(); Connection ds3 = ds.createDataSource().getConnection()) {
+            assertEquals(0, ds.getNumIdle());
+        }
 
         // Make sure MinEvictableIdleTimeMillis has elapsed
         Thread.sleep(100);
@@ -649,11 +699,11 @@ public class TestBasicDataSource extends TestConnectionPool {
     public void testMaxConnLifetimeExceeded() throws Exception {
         try {
             StackMessageLog.lock();
-            ds.setMaxConnLifetimeMillis(100);
-            final Connection conn = ds.getConnection();
-            assertEquals(1, ds.getNumActive());
-            Thread.sleep(500);
-            conn.close();
+            ds.setMaxConn(Duration.ofMillis(100));
+            try (Connection conn = ds.getConnection()) {
+                assertEquals(1, ds.getNumActive());
+                Thread.sleep(500);
+            }
             assertEquals(0, ds.getNumIdle());
             final String message = StackMessageLog.popMessage();
             Assertions.assertNotNull(message);
@@ -669,7 +719,7 @@ public class TestBasicDataSource extends TestConnectionPool {
         try {
             StackMessageLog.lock();
             StackMessageLog.clear();
-            ds.setMaxConnLifetimeMillis(100);
+            ds.setMaxConn(Duration.ofMillis(100));
             ds.setLogExpiredConnections(false);
             try (final Connection conn = ds.getConnection()) {
                 assertEquals(1, ds.getNumActive());
@@ -691,15 +741,7 @@ public class TestBasicDataSource extends TestConnectionPool {
     @Test
     public void testMaxTotalZero() throws Exception {
         ds.setMaxTotal(0);
-
-        try {
-            final Connection conn = ds.getConnection();
-            assertNotNull(conn);
-            fail("SQLException expected");
-
-        } catch (final SQLException e) {
-            // test OK
-        }
+        assertThrows(SQLException.class, ds::getConnection);
     }
 
     /**
@@ -715,10 +757,11 @@ public class TestBasicDataSource extends TestConnectionPool {
         properties.put("url", "jdbc:apache:commons:testdriver");
         properties.put("username", "foo");
         properties.put("password", "bar");
-        final BasicDataSource ds = BasicDataSourceFactory.createDataSource(properties);
-        final boolean original = ds.getConnectionPool().getLogAbandoned();
-        ds.setLogAbandoned(!original);
-        Assertions.assertNotEquals(original, ds.getConnectionPool().getLogAbandoned());
+        try (BasicDataSource ds = BasicDataSourceFactory.createDataSource(properties)) {
+            final boolean original = ds.getConnectionPool().getLogAbandoned();
+            ds.setLogAbandoned(!original);
+            Assertions.assertNotEquals(original, ds.getConnectionPool().getLogAbandoned());
+        }
     }
 
     @Test
@@ -726,12 +769,13 @@ public class TestBasicDataSource extends TestConnectionPool {
         // default: false
         assertFalse(ds.isAccessToUnderlyingConnectionAllowed());
 
-        final Connection conn = getConnection();
-        Connection dconn = ((DelegatingConnection<?>) conn).getDelegate();
-        assertNull(dconn);
+        try (Connection conn = getConnection()) {
+            Connection dconn = ((DelegatingConnection<?>) conn).getDelegate();
+            assertNull(dconn);
 
-        dconn = ((DelegatingConnection<?>) conn).getInnermostDelegate();
-        assertNull(dconn);
+            dconn = ((DelegatingConnection<?>) conn).getInnermostDelegate();
+            assertNull(dconn);
+        }
     }
 
     /**
@@ -743,10 +787,11 @@ public class TestBasicDataSource extends TestConnectionPool {
     public void testPoolCloseCheckedException() throws Exception {
         ds.setAccessToUnderlyingConnectionAllowed(true);  // Allow dirty tricks
 
+        final TesterConnection tc;
         // Get an idle connection into the pool
-        final Connection conn = ds.getConnection();
-        final TesterConnection tc = (TesterConnection) ((DelegatingConnection<?>) conn).getInnermostDelegate();
-        conn.close();
+        try (Connection conn = ds.getConnection()) {
+            tc = (TesterConnection) ((DelegatingConnection<?>) conn).getInnermostDelegate();
+        }
 
         // After returning the connection to the pool, bork it.
         // Don't try this at home - bad violation of pool contract!
@@ -775,9 +820,10 @@ public class TestBasicDataSource extends TestConnectionPool {
     public void testPoolCloseRTE() throws Exception {
         // RTE version of testPoolCloseCheckedException - see comments there.
         ds.setAccessToUnderlyingConnectionAllowed(true);
-        final Connection conn = ds.getConnection();
-        final TesterConnection tc = (TesterConnection) ((DelegatingConnection<?>) conn).getInnermostDelegate();
-        conn.close();
+        final TesterConnection tc;
+        try (Connection conn = ds.getConnection()) {
+            tc = (TesterConnection) ((DelegatingConnection<?>) conn).getInnermostDelegate();
+        }
         tc.setFailure(new IllegalStateException("boom"));
         try {
             StackMessageLog.lock();
@@ -813,35 +859,36 @@ public class TestBasicDataSource extends TestConnectionPool {
         ds.setTestWhileIdle(false);
         ds.setTestOnReturn(true);
 
-        final Connection conn = ds.getConnection();
-        assertNotNull(conn);
+        try (Connection conn = ds.getConnection()) {
+            assertNotNull(conn);
 
-        assertFalse(ds.getConnectionPool().getTestOnBorrow());
-        assertFalse(ds.getConnectionPool().getTestWhileIdle());
-        assertTrue(ds.getConnectionPool().getTestOnReturn());
+            assertFalse(ds.getConnectionPool().getTestOnBorrow());
+            assertFalse(ds.getConnectionPool().getTestWhileIdle());
+            assertTrue(ds.getConnectionPool().getTestOnReturn());
+        }
     }
 
     @Test
     public void testRestart() throws Exception {
         ds.setMaxTotal(2);
-        ds.setTimeBetweenEvictionRunsMillis(100);
+        ds.setDurationBetweenEvictionRuns(Duration.ofMillis(100));
         ds.setNumTestsPerEvictionRun(2);
-        ds.setMinEvictableIdleTimeMillis(60000);
+        ds.setMinEvictableIdle(Duration.ofMinutes(1));
         ds.setInitialSize(2);
         ds.setDefaultCatalog("foo");
-        final Connection conn1 = ds.getConnection();
-        Thread.sleep(200);
-        // Now set some property that will not have effect until restart
-        ds.setDefaultCatalog("bar");
-        ds.setInitialSize(1);
-        // restart will load new properties
-        ds.restart();
-        assertEquals("bar", ds.getDefaultCatalog());
-        assertEquals(1, ds.getInitialSize());
-        ds.getLogWriter();  // side effect is to init
-        assertEquals(0, ds.getNumActive());
-        assertEquals(1, ds.getNumIdle());
-        conn1.close();
+        try (Connection conn1 = ds.getConnection()) {
+            Thread.sleep(200);
+            // Now set some property that will not have effect until restart
+            ds.setDefaultCatalog("bar");
+            ds.setInitialSize(1);
+            // restart will load new properties
+            ds.restart();
+            assertEquals("bar", ds.getDefaultCatalog());
+            assertEquals(1, ds.getInitialSize());
+            ds.getLogWriter(); // side effect is to init
+            assertEquals(0, ds.getNumActive());
+            assertEquals(1, ds.getNumIdle());
+        }
         // verify old pool connection is not returned to pool
         assertEquals(1, ds.getNumIdle());
         ds.close();
@@ -857,25 +904,25 @@ public class TestBasicDataSource extends TestConnectionPool {
         ds.setDefaultReadOnly(Boolean.TRUE);
         ds.setDefaultAutoCommit(Boolean.FALSE);
 
-        final Connection conn = ds.getConnection();
-        assertNotNull(conn);
-        conn.close();
+        try (Connection conn = ds.getConnection()) {
+            assertNotNull(conn);
+        }
     }
 
     @Test
     public void testSetAutoCommitTrueOnClose() throws Exception {
         ds.setAccessToUnderlyingConnectionAllowed(true);
         ds.setDefaultAutoCommit(Boolean.FALSE);
+        final Connection dconn;
+        try (Connection conn = getConnection()) {
+            assertNotNull(conn);
+            assertFalse(conn.getAutoCommit());
 
-        final Connection conn = getConnection();
-        assertNotNull(conn);
-        assertFalse(conn.getAutoCommit());
+            dconn = ((DelegatingConnection<?>) conn).getInnermostDelegate();
+            assertNotNull(dconn);
+            assertFalse(dconn.getAutoCommit());
 
-        final Connection dconn = ((DelegatingConnection<?>) conn).getInnermostDelegate();
-        assertNotNull(dconn);
-        assertFalse(dconn.getAutoCommit());
-
-        conn.close();
+        }
 
         assertTrue(dconn.getAutoCommit());
     }
@@ -924,12 +971,7 @@ public class TestBasicDataSource extends TestConnectionPool {
         assertEquals("", ds.getConnectionProperties().getProperty("name1"));
 
         // null should throw a NullPointerException
-        try {
-            ds.setConnectionProperties(null);
-            fail("Expected NullPointerException");
-        } catch (final NullPointerException e) {
-            // expected
-        }
+        assertThrows(NullPointerException.class, () -> ds.setConnectionProperties(null));
     }
 
     @Test
@@ -1028,7 +1070,7 @@ public class TestBasicDataSource extends TestConnectionPool {
     public void testValidationQueryTimeoutNegative() throws Exception {
         ds.setTestOnBorrow(true);
         ds.setTestOnReturn(true);
-        ds.setValidationQueryTimeout(-1);
+        ds.setValidationQueryTimeout(Duration.ofSeconds(-1));
         try (final Connection con = ds.getConnection()) {
             // close right away.
         }
@@ -1038,7 +1080,7 @@ public class TestBasicDataSource extends TestConnectionPool {
     public void testValidationQueryTimeoutSucceed() throws Exception {
         ds.setTestOnBorrow(true);
         ds.setTestOnReturn(true);
-        ds.setValidationQueryTimeout(100); // Works for TesterStatement
+        ds.setValidationQueryTimeout(Duration.ofMillis(100)); // Works for TesterStatement
         try (final Connection con = ds.getConnection()) {
             // close right away.
         }
@@ -1048,7 +1090,7 @@ public class TestBasicDataSource extends TestConnectionPool {
     public void testValidationQueryTimeoutZero() throws Exception {
         ds.setTestOnBorrow(true);
         ds.setTestOnReturn(true);
-        ds.setValidationQueryTimeout(0);
+        ds.setValidationQueryTimeout(Duration.ZERO);
         try (final Connection con = ds.getConnection()) {
             // close right away.
         }
@@ -1057,14 +1099,9 @@ public class TestBasicDataSource extends TestConnectionPool {
     @Test
     public void testValidationQueryTimoutFail() {
         ds.setTestOnBorrow(true);
-        ds.setValidationQueryTimeout(3); // Too fast for TesterStatement
-        try (Connection c = ds.getConnection()) {
-            fail("expected SQLException");
-        } catch (final SQLException ex) {
-            if (!ex.toString().contains("timeout")) {
-                fail("expected timeout error message");
-            }
-        }
+        ds.setValidationQueryTimeout(Duration.ofSeconds(3)); // Too fast for TesterStatement
+        final SQLException e = assertThrows(SQLException.class, ds::getConnection);
+        assertTrue(e.toString().contains("timeout"));
     }
 }
 
@@ -1092,7 +1129,7 @@ class TesterConnectionDelayDriver extends TesterDriver {
         final int delay = Integer.parseInt(parsedUrl[parsedUrl.length - 1]);
         try {
             Thread.sleep(delay);
-        } catch(final InterruptedException ex) {
+        } catch (final InterruptedException ex) {
             Thread.currentThread().interrupt();
         }
         return super.connect(url, info);
