@@ -24,6 +24,7 @@ import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertNotSame;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.junit.jupiter.api.Assertions.fail;
 
@@ -33,6 +34,7 @@ import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Statement;
+import java.time.Duration;
 import java.util.Hashtable;
 import java.util.Random;
 import java.util.Stack;
@@ -51,11 +53,13 @@ import org.junit.jupiter.api.Test;
  */
 public abstract class TestConnectionPool {
 
+    private static final Duration MAX_WAIT_DURATION = Duration.ofMillis(100);
+
     protected class PoolTest implements Runnable {
         /**
          * The number of milliseconds to hold onto a database connection
          */
-        private final int connHoldTime;
+        private final Duration connHoldDuration;
 
         private final int numStatements;
 
@@ -83,13 +87,13 @@ public abstract class TestConnectionPool {
 
         private final boolean loopOnce; // If true, don't repeat loop
 
-        public PoolTest(final ThreadGroup threadGroup, final int connHoldTime, final boolean isStopOnException) {
-            this(threadGroup, connHoldTime, isStopOnException, false, 1);
+        public PoolTest(final ThreadGroup threadGroup, final Duration connHoldDuration, final boolean isStopOnException) {
+            this(threadGroup, connHoldDuration, isStopOnException, false, 1);
         }
 
-        private PoolTest(final ThreadGroup threadGroup, final int connHoldTime, final boolean isStopOnException, final boolean once, final int numStatements) {
+        private PoolTest(final ThreadGroup threadGroup, final Duration connHoldDuration, final boolean isStopOnException, final boolean once, final int numStatements) {
             this.loopOnce = once;
-            this.connHoldTime = connHoldTime;
+            this.connHoldDuration = connHoldDuration;
             stopOnException = isStopOnException;
             isRun = true; // Must be done here so main thread is guaranteed to be able to set it false
             thrown = null;
@@ -100,8 +104,8 @@ public abstract class TestConnectionPool {
             this.numStatements = numStatements;
         }
 
-        public PoolTest(final ThreadGroup threadGroup, final int connHoldTime, final boolean isStopOnException, final int numStatements) {
-            this(threadGroup, connHoldTime, isStopOnException, false, numStatements);
+        public PoolTest(final ThreadGroup threadGroup, final Duration connHoldDuration, final boolean isStopOnException, final int numStatements) {
+            this(threadGroup, connHoldDuration, isStopOnException, false, numStatements);
         }
 
         public Thread getThread() {
@@ -116,29 +120,28 @@ public abstract class TestConnectionPool {
                     loops++;
                     state = "Getting Connection";
                     preconnected = timeStampMillis();
-                    final Connection conn = getConnection();
-                    connHash = System.identityHashCode(((DelegatingConnection<?>)conn).getInnermostDelegate());
-                    connected = timeStampMillis();
-                    state = "Using Connection";
-                    assertNotNull(conn);
-                    final String sql = numStatements == 1 ? "select * from dual" : "select count " + random.nextInt(numStatements - 1);
-                    final PreparedStatement stmt =
-                        conn.prepareStatement(sql);
-                    assertNotNull(stmt);
-                    final ResultSet rset = stmt.executeQuery();
-                    assertNotNull(rset);
-                    assertTrue(rset.next());
-                    state = "Holding Connection";
-                    Thread.sleep(connHoldTime);
-                    state = "Closing ResultSet";
-                    rset.close();
-                    state = "Closing Statement";
-                    stmt.close();
-                    state = "Closing Connection";
-                    conn.close();
+                    try (Connection conn = getConnection()) {
+                        connHash = System.identityHashCode(((DelegatingConnection<?>) conn).getInnermostDelegate());
+                        connected = timeStampMillis();
+                        state = "Using Connection";
+                        assertNotNull(conn);
+                        final String sql = numStatements == 1 ? "select * from dual" : "select count " + random.nextInt(numStatements - 1);
+                        try (PreparedStatement stmt = conn.prepareStatement(sql)) {
+                            assertNotNull(stmt);
+                            try (ResultSet rset = stmt.executeQuery()) {
+                                assertNotNull(rset);
+                                assertTrue(rset.next());
+                                state = "Holding Connection";
+                                Thread.sleep(connHoldDuration.toMillis());
+                                state = "Closing ResultSet";
+                            }
+                            state = "Closing Statement";
+                        }
+                        state = "Closing Connection";
+                    }
                     postconnected = timeStampMillis();
                     state = "Closed";
-                    if (loopOnce){
+                    if (loopOnce) {
                         break; // Or could set isRun=false
                     }
                 }
@@ -191,22 +194,21 @@ public abstract class TestConnectionPool {
 
         @Override
         public void run() {
-            for(int i=0;i<_iter;i++) {
+            for (int i = 0; i < _iter; i++) {
                 try {
                     Thread.sleep(_random.nextInt(_delay));
-                } catch(final Exception e) {
+                } catch (final Exception e) {
                     // ignored
                 }
                 try (Connection conn = newConnection();
-                        PreparedStatement stmt = conn.prepareStatement(
-                                "select 'literal', SYSDATE from dual");
+                        PreparedStatement stmt = conn.prepareStatement("select 'literal', SYSDATE from dual");
                         ResultSet rset = stmt.executeQuery()) {
                     try {
                         Thread.sleep(_random.nextInt(_delay));
-                    } catch(final Exception e) {
+                    } catch (final Exception ignore) {
                         // ignored
                     }
-                } catch(final Exception e) {
+                } catch (final Exception e) {
                     e.printStackTrace();
                     _failed = true;
                     _complete = true;
@@ -228,7 +230,7 @@ public abstract class TestConnectionPool {
     private static final String DONE = "Done";
 
     /** Connections opened during the course of a test */
-    protected final Stack<Connection> connections = new Stack<>();
+    protected final Stack<Connection> connectionStack = new Stack<>();
 
     // ----------- Utility Methods ---------------------------------
 
@@ -236,7 +238,7 @@ public abstract class TestConnectionPool {
         assertFalse(conn.isClosed());
         assertFalse(isClosed(statement));
 
-        assertSame(conn,statement.getConnection(),
+        assertSame(conn, statement.getConnection(),
                 "statement.getConnection() should return the exact same connection instance that was used to create the statement");
 
         final ResultSet resultSet = statement.getResultSet();
@@ -275,23 +277,21 @@ public abstract class TestConnectionPool {
         }
     }
 
-    // ----------- tests ---------------------------------
-
     protected abstract Connection getConnection() throws Exception;
 
     protected int getMaxTotal() {
         return 10;
     }
 
-    protected long getMaxWaitMillis() {
-        return 100L;
+    protected Duration getMaxWaitDuration() {
+        return MAX_WAIT_DURATION;
     }
 
     protected String getUsername(final Connection conn) throws SQLException {
-        final Statement stmt = conn.createStatement();
-        final ResultSet rs = stmt.executeQuery("select username");
-        if (rs.next()) {
-            return rs.getString(1);
+        try (final Statement stmt = conn.createStatement(); final ResultSet rs = stmt.executeQuery("select username")) {
+            if (rs.next()) {
+                return rs.getString(1);
+            }
         }
         return null;
     }
@@ -329,17 +329,17 @@ public abstract class TestConnectionPool {
      * threads are expected to either throw exceptions or fail to complete. If {@code expectError} is false,
      * all threads are expected to complete successfully.
      *
-     * @param holdTime time in ms that a thread holds a connection before returning it to the pool
+     * @param holdDuration Duration that a thread holds a connection before returning it to the pool
      * @param expectError whether or not an error is expected
      * @param loopOnce whether threads should complete the borrow - hold - return cycle only once, or loop indefinitely
-     * @param maxWaitMillis passed in by client - has no impact on the test itself, but does get reported
+     * @param maxWaitDuration passed in by client - has no impact on the test itself, but does get reported
      *
      * @throws Exception
      */
-    protected void multipleThreads(final int holdTime,
+    protected void multipleThreads(final Duration holdDuration,
         final boolean expectError, final boolean loopOnce,
-        final long maxWaitMillis) throws Exception {
-        multipleThreads(holdTime, expectError, loopOnce, maxWaitMillis, 1, 2 * getMaxTotal(), 300);
+        final Duration maxWaitDuration) throws Exception {
+        multipleThreads(holdDuration, expectError, loopOnce, maxWaitDuration, 1, 2 * getMaxTotal(), 300);
     }
 
     /**
@@ -349,123 +349,127 @@ public abstract class TestConnectionPool {
      * threads are expected to either throw exceptions or fail to complete. If {@code expectError} is false,
      * all threads are expected to complete successfully.  Threads are stopped after {@code duration} ms.
      *
-     * @param holdTime time in ms that a thread holds a connection before returning it to the pool
+     * @param holdDuration Duration that a thread holds a connection before returning it to the pool
      * @param expectError whether or not an error is expected
      * @param loopOnce whether threads should complete the borrow - hold - return cycle only once, or loop indefinitely
-     * @param maxWaitMillis passed in by client - has no impact on the test itself, but does get reported
+     * @param maxWaitDuration passed in by client - has no impact on the test itself, but does get reported
      * @param numThreads the number of threads
      * @param duration duration in ms of test
      *
      * @throws Exception
      */
-    protected void multipleThreads(final int holdTime,
+    protected void multipleThreads(final Duration holdDuration,
             final boolean expectError, final boolean loopOnce,
-            final long maxWaitMillis, final int numStatements, final int numThreads, final long duration) throws Exception {
-                final long startTimeMillis = timeStampMillis();
-                final PoolTest[] pts = new PoolTest[numThreads];
-                // Catch Exception so we can stop all threads if one fails
-                final ThreadGroup threadGroup = new ThreadGroup("foo") {
-                    @Override
-                    public void uncaughtException(final Thread t, final Throwable e) {
-                        for (final PoolTest pt : pts) {
-                            pt.stop();
-                        }
-                    }
-                };
-                // Create all the threads
-                for (int i = 0; i < pts.length; i++) {
-                    pts[i] = new PoolTest(threadGroup, holdTime, expectError, loopOnce, numStatements);
-                }
-                // Start all the threads
-                for (final PoolTest pt : pts) {
-                    pt.start();
-                }
-
-                // Give all threads a chance to start and succeed
-                Thread.sleep(duration);
-
-                // Stop threads
+        final Duration maxWaitDuration, final int numStatements, final int numThreads, final long duration) throws Exception {
+        final long startTimeMillis = timeStampMillis();
+        final PoolTest[] pts = new PoolTest[numThreads];
+        // Catch Exception so we can stop all threads if one fails
+        final ThreadGroup threadGroup = new ThreadGroup("foo") {
+            @Override
+            public void uncaughtException(final Thread t, final Throwable e) {
                 for (final PoolTest pt : pts) {
                     pt.stop();
                 }
+            }
+        };
+        // Create all the threads
+        for (int i = 0; i < pts.length; i++) {
+            pts[i] = new PoolTest(threadGroup, holdDuration, expectError, loopOnce, numStatements);
+        }
+        // Start all the threads
+        for (final PoolTest pt : pts) {
+            pt.start();
+        }
 
-                /*
-                 * Wait for all threads to terminate.
-                 * This is essential to ensure that all threads have a chance to update success[0]
-                 * and to ensure that the variable is published correctly.
-                 */
-                int done=0;
-                int failed=0;
-                int didNotRun = 0;
-                int loops=0;
-                for (final PoolTest poolTest : pts) {
-                    poolTest.thread.join();
-                    loops += poolTest.loops;
-                    final String state = poolTest.state;
-                    if (DONE.equals(state)){
-                        done++;
-                    }
-                    if (poolTest.loops == 0){
-                        didNotRun++;
-                    }
-                    final Throwable thrown = poolTest.thrown;
-                    if (thrown != null) {
-                        failed++;
-                        if (!expectError || !(thrown instanceof SQLException)){
-                            System.err.println("Unexpected error: " + thrown.getMessage());
-                        }
-                    }
-                }
+        // Give all threads a chance to start and succeed
+        Thread.sleep(duration);
 
-                final long timeMillis = timeStampMillis() - startTimeMillis;
-                println("Multithread test time = " + timeMillis
-                        + " ms. Threads: " + pts.length
-                        + ". Loops: " + loops
-                        + ". Hold time: " + holdTime
-                        + ". maxWaitMillis: " + maxWaitMillis
-                        + ". Done: " + done
-                        + ". Did not run: " + didNotRun
-                        + ". Failed: " + failed
-                        + ". expectError: " + expectError
-                        );
-                if (expectError) {
-                    if (DISPLAY_THREAD_DETAILS || pts.length/2 != failed){
-                        final long offset = pts[0].createdMillis - 1000; // To reduce size of output numbers, but ensure they have 4 digits
-                        println("Offset: "+offset);
-                        for (int i = 0; i < pts.length; i++) {
-                            final PoolTest pt = pts[i];
-                            println(
-                                    "Pre: " + (pt.preconnected-offset) // First, so can sort on this easily
-                                    + ". Post: " + (pt.postconnected != 0 ? Long.toString(pt.postconnected-offset): "-")
-                                    + ". Hash: " + pt.connHash
-                                    + ". Startup: " + (pt.started-pt.createdMillis)
-                                    + ". getConn(): " + (pt.connected != 0 ? Long.toString(pt.connected-pt.preconnected) : "-")
-                                    + ". Runtime: " + (pt.ended-pt.started)
-                                    + ". IDX: " + i
-                                    + ". Loops: " + pt.loops
-                                    + ". State: " + pt.state
-                                    + ". thrown: "+ pt.thrown
-                                    + "."
-                                    );
-                        }
-                    }
-                    if (didNotRun > 0){
-                        println("NOTE: some threads did not run the code: "+didNotRun);
-                    }
-                    // Perform initial sanity check:
-                    assertTrue(failed > 0, "Expected some of the threads to fail");
-                    // Assume that threads that did not run would have timed out.
-                    assertEquals(pts.length / 2, failed + didNotRun, "WARNING: Expected half the threads to fail");
-                } else {
-                    assertEquals(0, failed, "Did not expect any threads to fail");
+        // Stop threads
+        for (final PoolTest pt : pts) {
+            pt.stop();
+        }
+
+        /*
+         * Wait for all threads to terminate. This is essential to ensure that all threads have a chance to update success[0]
+         * and to ensure that the variable is published correctly.
+         */
+        int done = 0;
+        int failed = 0;
+        int didNotRun = 0;
+        int loops = 0;
+        for (final PoolTest poolTest : pts) {
+            poolTest.thread.join();
+            loops += poolTest.loops;
+            final String state = poolTest.state;
+            if (DONE.equals(state)) {
+                done++;
+            }
+            if (poolTest.loops == 0) {
+                didNotRun++;
+            }
+            final Throwable thrown = poolTest.thrown;
+            if (thrown != null) {
+                failed++;
+                if (!expectError || !(thrown instanceof SQLException)) {
+                    System.err.println("Unexpected error: " + thrown.getMessage());
                 }
             }
+        }
 
-    /** Acquire a connection and push it onto the connections stack */
+        final long timeMillis = timeStampMillis() - startTimeMillis;
+        // @formatter:off
+        println("Multithread test time = " + timeMillis
+            + " ms. Threads: " + pts.length
+            + ". Loops: " + loops
+            + ". Hold time: " + holdDuration
+            + ". maxWaitMillis: " + maxWaitDuration
+            + ". Done: " + done
+            + ". Did not run: " + didNotRun
+            + ". Failed: " + failed
+            + ". expectError: " + expectError);
+        // @formatter:on
+        if (expectError) {
+            if (DISPLAY_THREAD_DETAILS || pts.length / 2 != failed) {
+                final long offset = pts[0].createdMillis - 1000; // To reduce size of output numbers, but ensure they have 4 digits
+                println("Offset: " + offset);
+                for (int i = 0; i < pts.length; i++) {
+                    final PoolTest pt = pts[i];
+                    // @formatter:off
+                    println("Pre: " + (pt.preconnected-offset) // First, so can sort on this easily
+                        + ". Post: " + (pt.postconnected != 0 ? Long.toString(pt.postconnected-offset): "-")
+                        + ". Hash: " + pt.connHash
+                        + ". Startup: " + (pt.started-pt.createdMillis)
+                        + ". getConn(): " + (pt.connected != 0 ? Long.toString(pt.connected-pt.preconnected) : "-")
+                        + ". Runtime: " + (pt.ended-pt.started)
+                        + ". IDX: " + i
+                        + ". Loops: " + pt.loops
+                        + ". State: " + pt.state
+                        + ". thrown: "+ pt.thrown
+                        + ".");
+                    // @formatter:on
+                }
+            }
+            if (didNotRun > 0) {
+                println("NOTE: some threads did not run the code: " + didNotRun);
+            }
+            // Perform initial sanity check:
+            assertTrue(failed > 0, "Expected some of the threads to fail");
+            // Assume that threads that did not run would have timed out.
+            assertEquals(pts.length / 2, failed + didNotRun, "WARNING: Expected half the threads to fail");
+        } else {
+            assertEquals(0, failed, "Did not expect any threads to fail");
+        }
+    }
+
+    /** 
+     * Acquires a new connection and push it onto the connections stack.
+     * 
+     * @return a new connection.
+     * @throws Exception Defined in subclasses.
+     */
+    @SuppressWarnings("resource") // Caller closes
     protected Connection newConnection() throws Exception {
-        final Connection connection = getConnection();
-        connections.push(connection);
-        return connection;
+        return connectionStack.push(getConnection());
     }
 
     void println(final String string) {
@@ -477,15 +481,8 @@ public abstract class TestConnectionPool {
     @AfterEach
     public void tearDown() throws Exception {
         // Close any connections opened by the test
-        while (!connections.isEmpty()) {
-            Connection conn = connections.pop();
-            try {
-                conn.close();
-            } catch (final Exception ex) {
-                // ignore
-            } finally {
-                conn = null;
-            }
+        while (!connectionStack.isEmpty()) {
+            Utils.closeQuietly((AutoCloseable) connectionStack.pop());
         }
     }
 
@@ -550,21 +547,21 @@ public abstract class TestConnectionPool {
 
     @Test
     public void testCanCloseCallableStatementTwice() throws Exception {
-        final Connection conn = newConnection();
-        assertNotNull(conn);
-        assertFalse(conn.isClosed());
-        for(int i=0;i<2;i++) { // loop to show we *can* close again once we've borrowed it from the pool again
-            final PreparedStatement stmt = conn.prepareCall("select * from dual");
-            assertNotNull(stmt);
-            assertFalse(isClosed(stmt));
-            stmt.close();
-            assertTrue(isClosed(stmt));
-            stmt.close();
-            assertTrue(isClosed(stmt));
-            stmt.close();
-            assertTrue(isClosed(stmt));
+        try (Connection conn = newConnection()) {
+            assertNotNull(conn);
+            assertFalse(conn.isClosed());
+            for (int i = 0; i < 2; i++) { // loop to show we *can* close again once we've borrowed it from the pool again
+                final PreparedStatement stmt = conn.prepareCall("select * from dual");
+                assertNotNull(stmt);
+                assertFalse(isClosed(stmt));
+                stmt.close();
+                assertTrue(isClosed(stmt));
+                stmt.close();
+                assertTrue(isClosed(stmt));
+                stmt.close();
+                assertTrue(isClosed(stmt));
+            }
         }
-        conn.close();
     }
 
     /**
@@ -586,42 +583,42 @@ public abstract class TestConnectionPool {
 
     @Test
     public void testCanClosePreparedStatementTwice() throws Exception {
-        final Connection conn = newConnection();
-        assertNotNull(conn);
-        assertFalse(conn.isClosed());
-        for(int i=0;i<2;i++) { // loop to show we *can* close again once we've borrowed it from the pool again
-            final PreparedStatement stmt = conn.prepareStatement("select * from dual");
-            assertNotNull(stmt);
-            assertFalse(isClosed(stmt));
-            stmt.close();
-            assertTrue(isClosed(stmt));
-            stmt.close();
-            assertTrue(isClosed(stmt));
-            stmt.close();
-            assertTrue(isClosed(stmt));
+        try (Connection conn = newConnection()) {
+            assertNotNull(conn);
+            assertFalse(conn.isClosed());
+            for (int i = 0; i < 2; i++) { // loop to show we *can* close again once we've borrowed it from the pool again
+                final PreparedStatement stmt = conn.prepareStatement("select * from dual");
+                assertNotNull(stmt);
+                assertFalse(isClosed(stmt));
+                stmt.close();
+                assertTrue(isClosed(stmt));
+                stmt.close();
+                assertTrue(isClosed(stmt));
+                stmt.close();
+                assertTrue(isClosed(stmt));
+            }
         }
-        conn.close();
     }
 
     @Test
     public void testCanCloseResultSetTwice() throws Exception {
-        final Connection conn = newConnection();
-        assertNotNull(conn);
-        assertFalse(conn.isClosed());
-        for(int i=0;i<2;i++) { // loop to show we *can* close again once we've borrowed it from the pool again
-            final PreparedStatement stmt = conn.prepareStatement("select * from dual");
-            assertNotNull(stmt);
-            final ResultSet rset = stmt.executeQuery();
-            assertNotNull(rset);
-            assertFalse(isClosed(rset));
-            rset.close();
-            assertTrue(isClosed(rset));
-            rset.close();
-            assertTrue(isClosed(rset));
-            rset.close();
-            assertTrue(isClosed(rset));
+        try (Connection conn = newConnection()) {
+            assertNotNull(conn);
+            assertFalse(conn.isClosed());
+            for (int i = 0; i < 2; i++) { // loop to show we *can* close again once we've borrowed it from the pool again
+                final PreparedStatement stmt = conn.prepareStatement("select * from dual");
+                assertNotNull(stmt);
+                final ResultSet rset = stmt.executeQuery();
+                assertNotNull(rset);
+                assertFalse(isClosed(rset));
+                rset.close();
+                assertTrue(isClosed(rset));
+                rset.close();
+                assertTrue(isClosed(rset));
+                rset.close();
+                assertTrue(isClosed(rset));
+            }
         }
-        conn.close();
     }
 
     @Test
@@ -629,7 +626,7 @@ public abstract class TestConnectionPool {
         final Connection conn = newConnection();
         assertNotNull(conn);
         assertFalse(conn.isClosed());
-        for(int i=0;i<2;i++) { // loop to show we *can* close again once we've borrowed it from the pool again
+        for (int i = 0; i < 2; i++) { // loop to show we *can* close again once we've borrowed it from the pool again
             final Statement stmt = conn.createStatement();
             assertNotNull(stmt);
             assertFalse(isClosed(stmt));
@@ -651,7 +648,8 @@ public abstract class TestConnectionPool {
             assertNotNull(c[i]);
 
             // generate SQLWarning on connection
-            try (CallableStatement cs = c[i].prepareCall("warning")){
+            try (CallableStatement cs = c[i].prepareCall("warning")) {
+                // empty
             }
         }
 
@@ -742,18 +740,22 @@ public abstract class TestConnectionPool {
 
     @Test
     public void testIsClosed() throws Exception {
-        for(int i=0;i<getMaxTotal();i++) {
+        for (int i = 0; i < getMaxTotal(); i++) {
+            @SuppressWarnings("resource")
             final Connection conn = newConnection();
-            assertNotNull(conn);
-            assertFalse(conn.isClosed());
-            final PreparedStatement stmt = conn.prepareStatement("select * from dual");
-            assertNotNull(stmt);
-            final ResultSet rset = stmt.executeQuery();
-            assertNotNull(rset);
-            assertTrue(rset.next());
-            rset.close();
-            stmt.close();
-            conn.close();
+            try {
+                assertNotNull(conn);
+                assertFalse(conn.isClosed());
+                try (PreparedStatement stmt = conn.prepareStatement("select * from dual")) {
+                    assertNotNull(stmt);
+                    try (ResultSet rset = stmt.executeQuery()) {
+                        assertNotNull(rset);
+                        assertTrue(rset.next());
+                    }
+                }
+            } finally {
+                conn.close();
+            }
             assertTrue(conn.isClosed());
         }
     }
@@ -766,13 +768,9 @@ public abstract class TestConnectionPool {
             assertNotNull(c[i]);
         }
 
-        try {
-            newConnection();
-            fail("Allowed to open more than DefaultMaxTotal connections.");
-        } catch (final java.sql.SQLException e) {
-            // should only be able to open 10 connections, so this test should
-            // throw an exception
-        }
+        // should only be able to open 10 connections, so this test should
+        // throw an exception
+        assertThrows(SQLException.class, this::newConnection);
 
         for (final Connection element : c) {
             element.close();
@@ -783,15 +781,15 @@ public abstract class TestConnectionPool {
     // wrong order of passivate/close when a rset isn't closed
     @Test
     public void testNoRsetClose() throws Exception {
-        final Connection conn = newConnection();
-        assertNotNull(conn);
-        final PreparedStatement stmt = conn.prepareStatement("test");
-        assertNotNull(stmt);
-        final ResultSet rset = stmt.getResultSet();
-        assertNotNull(rset);
-        // forget to close the resultset: rset.close();
-        stmt.close();
-        conn.close();
+        try (Connection conn = newConnection()) {
+            assertNotNull(conn);
+            try (PreparedStatement stmt = conn.prepareStatement("test")) {
+                assertNotNull(stmt);
+                final ResultSet rset = stmt.getResultSet();
+                assertNotNull(rset);
+                // forget to close the resultset: rset.close();
+            }
+        }
     }
 
     @Test
@@ -830,19 +828,18 @@ public abstract class TestConnectionPool {
         // the new ones come from the pool
         for (final Connection element : c) {
             element.close();
-            final Connection con = newConnection();
-            final Connection underCon =
-                ((DelegatingConnection<?>) con).getInnermostDelegate();
-            assertNotNull(underCon, "Failed to get connection");
-            boolean found = false;
-            for (int j = 0; j < c.length; j++) {
-                if (underCon == u[j]) {
-                    found = true;
-                    break;
+            try (Connection con = newConnection()) {
+                final Connection underCon = ((DelegatingConnection<?>) con).getInnermostDelegate();
+                assertNotNull(underCon, "Failed to get connection");
+                boolean found = false;
+                for (int j = 0; j < c.length; j++) {
+                    if (underCon == u[j]) {
+                        found = true;
+                        break;
+                    }
                 }
+                assertTrue(found, "New connection not from pool");
             }
-            assertTrue(found, "New connection not from pool");
-            con.close();
         }
     }
 
@@ -850,125 +847,118 @@ public abstract class TestConnectionPool {
     // and Concurrency if statement pooling is not enabled
     // https://issues.apache.org/bugzilla/show_bug.cgi?id=24328
     @Test
-    public void testPrepareStatementOptions() throws Exception
-    {
-        final Connection conn = newConnection();
-        assertNotNull(conn);
-        final PreparedStatement stmt = conn.prepareStatement("select * from dual",
-            ResultSet.TYPE_SCROLL_SENSITIVE, ResultSet.CONCUR_UPDATABLE);
-        assertNotNull(stmt);
-        final ResultSet rset = stmt.executeQuery();
-        assertNotNull(rset);
-        assertTrue(rset.next());
-
-        assertEquals(ResultSet.TYPE_SCROLL_SENSITIVE, rset.getType());
-        assertEquals(ResultSet.CONCUR_UPDATABLE, rset.getConcurrency());
-
-        rset.close();
-        stmt.close();
-        conn.close();
-    }
-
-            @Test
-            public void testRepeatedBorrowAndReturn() throws Exception {
-                for(int i=0;i<100;i++) {
-                    final Connection conn = newConnection();
-                    assertNotNull(conn);
-                    final PreparedStatement stmt = conn.prepareStatement("select * from dual");
-                    assertNotNull(stmt);
-                    final ResultSet rset = stmt.executeQuery();
+    public void testPrepareStatementOptions() throws Exception {
+        try (Connection conn = newConnection()) {
+            assertNotNull(conn);
+            try (PreparedStatement stmt = conn.prepareStatement("select * from dual", ResultSet.TYPE_SCROLL_SENSITIVE, ResultSet.CONCUR_UPDATABLE)) {
+                assertNotNull(stmt);
+                try (ResultSet rset = stmt.executeQuery()) {
                     assertNotNull(rset);
                     assertTrue(rset.next());
-                    rset.close();
-                    stmt.close();
-                    conn.close();
+
+                    assertEquals(ResultSet.TYPE_SCROLL_SENSITIVE, rset.getType());
+                    assertEquals(ResultSet.CONCUR_UPDATABLE, rset.getConcurrency());
+
                 }
             }
+        }
+    }
+
+    @Test
+    public void testRepeatedBorrowAndReturn() throws Exception {
+        for (int i = 0; i < 100; i++) {
+            try (Connection conn = newConnection()) {
+                assertNotNull(conn);
+                try (PreparedStatement stmt = conn.prepareStatement("select * from dual")) {
+                    assertNotNull(stmt);
+                    try (ResultSet rset = stmt.executeQuery()) {
+                        assertNotNull(rset);
+                        assertTrue(rset.next());
+                    }
+                }
+            }
+        }
+    }
 
     @Test
     public void testSimple() throws Exception {
-        final Connection conn = newConnection();
-        assertNotNull(conn);
-        final PreparedStatement stmt = conn.prepareStatement("select * from dual");
-        assertNotNull(stmt);
-        final ResultSet rset = stmt.executeQuery();
-        assertNotNull(rset);
-        assertTrue(rset.next());
-        rset.close();
-        stmt.close();
-        conn.close();
+        try (Connection conn = newConnection()) {
+            assertNotNull(conn);
+            try (PreparedStatement stmt = conn.prepareStatement("select * from dual")) {
+                assertNotNull(stmt);
+                try (ResultSet rset = stmt.executeQuery()) {
+                    assertNotNull(rset);
+                    assertTrue(rset.next());
+                }
+            }
+        }
     }
 
     @Test
     public void testSimple2() throws Exception {
-        Connection conn = newConnection();
+        @SuppressWarnings("resource")
+        final Connection conn = newConnection();
         assertNotNull(conn);
-        {
-            final PreparedStatement stmt = conn.prepareStatement("select * from dual");
-            assertNotNull(stmt);
-            final ResultSet rset = stmt.executeQuery();
-            assertNotNull(rset);
-            assertTrue(rset.next());
-            rset.close();
-            stmt.close();
-        }
-        {
-            final PreparedStatement stmt = conn.prepareStatement("select * from dual");
-            assertNotNull(stmt);
-            final ResultSet rset = stmt.executeQuery();
-            assertNotNull(rset);
-            assertTrue(rset.next());
-            rset.close();
-            stmt.close();
-        }
-        conn.close();
-        try (Statement s = conn.createStatement()){
-            fail("Can't use closed connections");
-        } catch(final SQLException e) {
-            // expected
+        try {
+            try (PreparedStatement stmt = conn.prepareStatement("select * from dual")) {
+                assertNotNull(stmt);
+                try (ResultSet rset = stmt.executeQuery()) {
+                    assertNotNull(rset);
+                    assertTrue(rset.next());
+                }
+            }
+            try (PreparedStatement stmt = conn.prepareStatement("select * from dual")) {
+                assertNotNull(stmt);
+                try (ResultSet rset = stmt.executeQuery()) {
+                    assertNotNull(rset);
+                    assertTrue(rset.next());
+                }
+            }
+        } finally {
+            conn.close();
         }
+        assertThrows(SQLException.class, conn::createStatement, "Can't use closed connections");
 
-        conn = newConnection();
-        assertNotNull(conn);
-        {
-            final PreparedStatement stmt = conn.prepareStatement("select * from dual");
-            assertNotNull(stmt);
-            final ResultSet rset = stmt.executeQuery();
-            assertNotNull(rset);
-            assertTrue(rset.next());
-            rset.close();
-            stmt.close();
+        try (Connection conn2 = newConnection()) {
+            assertNotNull(conn2);
+            {
+                try (PreparedStatement stmt = conn2.prepareStatement("select * from dual")) {
+                    assertNotNull(stmt);
+                    try (ResultSet rset = stmt.executeQuery()) {
+                        assertNotNull(rset);
+                        assertTrue(rset.next());
+                    }
+                }
+            }
+            {
+                try (PreparedStatement stmt = conn2.prepareStatement("select * from dual")) {
+                    assertNotNull(stmt);
+                    try (ResultSet rset = stmt.executeQuery()) {
+                        assertNotNull(rset);
+                        assertTrue(rset.next());
+                    }
+                }
+            }
         }
-        {
-            final PreparedStatement stmt = conn.prepareStatement("select * from dual");
-            assertNotNull(stmt);
-            final ResultSet rset = stmt.executeQuery();
-            assertNotNull(rset);
-            assertTrue(rset.next());
-            rset.close();
-            stmt.close();
-        }
-        conn.close();
-        conn = null;
     }
 
     @Test
     public void testThreaded() {
         final TestThread[] threads = new TestThread[getMaxTotal()];
-        for(int i=0;i<threads.length;i++) {
-            threads[i] = new TestThread(50,50);
+        for (int i = 0; i < threads.length; i++) {
+            threads[i] = new TestThread(50, 50);
             final Thread t = new Thread(threads[i]);
             t.start();
         }
-        for(int i=0;i<threads.length;i++) {
-            while(!threads[i].complete()) {
+        for (int i = 0; i < threads.length; i++) {
+            while (!threads[i].complete()) {
                 try {
                     Thread.sleep(100L);
-                } catch(final Exception e) {
+                } catch (final Exception e) {
                     // ignored
                 }
             }
-            if(threads[i] != null && threads[i].failed()) {
+            if (threads[i] != null && threads[i].failed()) {
                 fail("Thread failed: " + i);
             }
         }
