@@ -54,19 +54,21 @@ public class TesterResultSet extends AbandonedTrace implements ResultSet {
     public TesterResultSet(final Statement stmt) {
         _statement = stmt;
     }
+
     public TesterResultSet(final Statement stmt, final int type, final int concurrency) {
         _statement = stmt;
         _data = null;
         _type = type;
         _concurrency = concurrency;
     }
+
     public TesterResultSet(final Statement stmt, final Object[][] data) {
         _statement = stmt;
         _data = data;
     }
 
     @Override
-    public boolean absolute( final int row ) throws SQLException {
+    public boolean absolute(final int row) throws SQLException {
         checkOpen();
         return false;
     }
@@ -87,7 +89,7 @@ public class TesterResultSet extends AbandonedTrace implements ResultSet {
     }
 
     protected void checkOpen() throws SQLException {
-        if(!_open) {
+        if (!_open) {
             throw new SQLException("ResultSet is closed.");
         }
     }
@@ -109,7 +111,7 @@ public class TesterResultSet extends AbandonedTrace implements ResultSet {
 
         // Not all result sets are generated from statements eg DatabaseMetaData
         if (_statement != null) {
-            ((TesterStatement)_statement)._resultSet = null;
+            ((TesterStatement) _statement)._resultSet = null;
         }
 
         _open = false;
@@ -223,19 +225,19 @@ public class TesterResultSet extends AbandonedTrace implements ResultSet {
     @Override
     public byte getByte(final int columnIndex) throws SQLException {
         checkOpen();
-        return (byte)columnIndex;
+        return (byte) columnIndex;
     }
 
     @Override
     public byte getByte(final String columnName) throws SQLException {
         checkOpen();
-        return (byte)columnName.hashCode();
+        return (byte) columnName.hashCode();
     }
 
     @Override
     public byte[] getBytes(final int columnIndex) throws SQLException {
         checkOpen();
-        return new byte[] { (byte)columnIndex };
+        return new byte[] { (byte) columnIndex };
     }
 
     @Override
@@ -285,11 +287,11 @@ public class TesterResultSet extends AbandonedTrace implements ResultSet {
         return null;
     }
 
-   @Override
-public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws SQLException {
-    checkOpen();
-    return null;
-}
+    @Override
+    public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws SQLException {
+        checkOpen();
+        return null;
+    }
 
     @Override
     public java.sql.Date getDate(final String columnName) throws SQLException {
@@ -327,7 +329,6 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
         return 2;
     }
 
-
     @Override
     public float getFloat(final int columnIndex) throws SQLException {
         checkOpen();
@@ -348,7 +349,7 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
     @Override
     public int getInt(final int columnIndex) throws SQLException {
         checkOpen();
-        return (short)columnIndex;
+        return (short) columnIndex;
     }
 
     @Override
@@ -409,7 +410,7 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
     public Object getObject(final int columnIndex) throws SQLException {
         checkOpen();
         if (_data != null) {
-            return _data[_currentRow][columnIndex-1];
+            return _data[_currentRow][columnIndex - 1];
         }
         return new Object();
     }
@@ -420,7 +421,7 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
     }
 
     @Override
-    public Object getObject(final int i, final Map<String,Class<?>> map) throws SQLException {
+    public Object getObject(final int i, final Map<String, Class<?>> map) throws SQLException {
         checkOpen();
         return new Object();
     }
@@ -432,13 +433,12 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
     }
 
     @Override
-    public <T> T getObject(final String columnLabel, final Class<T> type)
-            throws SQLException {
+    public <T> T getObject(final String columnLabel, final Class<T> type) throws SQLException {
         throw new SQLException("Not implemented.");
     }
 
     @Override
-    public Object getObject(final String colName, final Map<String,Class<?>> map) throws SQLException {
+    public Object getObject(final String colName, final Map<String, Class<?>> map) throws SQLException {
         checkOpen();
         return colName;
     }
@@ -474,13 +474,13 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
     @Override
     public short getShort(final int columnIndex) throws SQLException {
         checkOpen();
-        return (short)columnIndex;
+        return (short) columnIndex;
     }
 
     @Override
     public short getShort(final String columnName) throws SQLException {
         checkOpen();
-        return (short)columnName.hashCode();
+        return (short) columnName.hashCode();
     }
 
     @Override
@@ -559,10 +559,8 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
         return null;
     }
 
-
     @Override
-    public java.sql.Timestamp getTimestamp(final String columnName, final Calendar cal)
-      throws SQLException {
+    public java.sql.Timestamp getTimestamp(final String columnName, final Calendar cal) throws SQLException {
         checkOpen();
         return null;
     }
@@ -600,9 +598,9 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
 
     @Override
     public SQLWarning getWarnings() throws SQLException {
-           checkOpen();
-           return null;
-       }
+        checkOpen();
+        return null;
+    }
 
     @Override
     public void insertRow() throws SQLException {
@@ -685,7 +683,7 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
     }
 
     @Override
-    public boolean relative( final int rows ) throws SQLException {
+    public boolean relative(final int rows) throws SQLException {
         checkOpen();
         return false;
     }
@@ -728,14 +726,12 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
     }
 
     @Override
-    public void updateArray(final int columnIndex, final java.sql.Array x)
-        throws SQLException {
+    public void updateArray(final int columnIndex, final java.sql.Array x) throws SQLException {
         throw new SQLException("Not implemented.");
     }
 
     @Override
-    public void updateArray(final String columnName, final java.sql.Array x)
-        throws SQLException {
+    public void updateArray(final String columnName, final java.sql.Array x) throws SQLException {
         throw new SQLException("Not implemented.");
     }
 
@@ -744,16 +740,13 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
         throw new SQLException("Not implemented.");
     }
 
-
     @Override
     public void updateAsciiStream(final int columnIndex, final InputStream inputStream, final long length) throws SQLException {
         throw new SQLException("Not implemented.");
     }
 
     @Override
-    public void updateAsciiStream(final int columnIndex,
-               final java.io.InputStream x,
-               final int length) throws SQLException {
+    public void updateAsciiStream(final int columnIndex, final java.io.InputStream x, final int length) throws SQLException {
         checkOpen();
     }
 
@@ -768,9 +761,7 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
     }
 
     @Override
-    public void updateAsciiStream(final String columnName,
-               final java.io.InputStream x,
-               final int length) throws SQLException {
+    public void updateAsciiStream(final String columnName, final java.io.InputStream x, final int length) throws SQLException {
         checkOpen();
     }
 
@@ -795,9 +786,7 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
     }
 
     @Override
-    public void updateBinaryStream(final int columnIndex,
-                final java.io.InputStream x,
-                final int length) throws SQLException {
+    public void updateBinaryStream(final int columnIndex, final java.io.InputStream x, final int length) throws SQLException {
         checkOpen();
     }
 
@@ -812,9 +801,7 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
     }
 
     @Override
-    public void updateBinaryStream(final String columnName,
-                final java.io.InputStream x,
-                final int length) throws SQLException {
+    public void updateBinaryStream(final String columnName, final java.io.InputStream x, final int length) throws SQLException {
         checkOpen();
     }
 
@@ -829,8 +816,7 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
     }
 
     @Override
-    public void updateBlob(final int columnIndex, final java.sql.Blob x)
-        throws SQLException {
+    public void updateBlob(final int columnIndex, final java.sql.Blob x) throws SQLException {
         throw new SQLException("Not implemented.");
     }
 
@@ -845,8 +831,7 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
     }
 
     @Override
-    public void updateBlob(final String columnName, final java.sql.Blob x)
-        throws SQLException {
+    public void updateBlob(final String columnName, final java.sql.Blob x) throws SQLException {
         throw new SQLException("Not implemented.");
     }
 
@@ -881,9 +866,7 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
     }
 
     @Override
-    public void updateCharacterStream(final int columnIndex,
-                 final java.io.Reader x,
-                 final int length) throws SQLException {
+    public void updateCharacterStream(final int columnIndex, final java.io.Reader x, final int length) throws SQLException {
         checkOpen();
     }
 
@@ -892,16 +875,13 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
         throw new SQLException("Not implemented.");
     }
 
-
     @Override
     public void updateCharacterStream(final int columnIndex, final Reader reader, final long length) throws SQLException {
         throw new SQLException("Not implemented.");
     }
 
     @Override
-    public void updateCharacterStream(final String columnName,
-                 final java.io.Reader reader,
-                 final int length) throws SQLException {
+    public void updateCharacterStream(final String columnName, final java.io.Reader reader, final int length) throws SQLException {
         checkOpen();
     }
 
@@ -916,8 +896,7 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
     }
 
     @Override
-    public void updateClob(final int columnIndex, final java.sql.Clob x)
-        throws SQLException {
+    public void updateClob(final int columnIndex, final java.sql.Clob x) throws SQLException {
         throw new SQLException("Not implemented.");
     }
 
@@ -932,8 +911,7 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
     }
 
     @Override
-    public void updateClob(final String columnName, final java.sql.Clob x)
-        throws SQLException {
+    public void updateClob(final String columnName, final java.sql.Clob x) throws SQLException {
         throw new SQLException("Not implemented.");
     }
 
@@ -1103,8 +1081,7 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
     }
 
     @Override
-    public void updateObject(final String columnLabel, final Object x, final SQLType targetSqlType, final int scaleOrLength)
-            throws SQLException {
+    public void updateObject(final String columnLabel, final Object x, final SQLType targetSqlType, final int scaleOrLength) throws SQLException {
         checkOpen();
     }
 
@@ -1179,8 +1156,7 @@ public java.sql.Date getDate(final int columnIndex, final Calendar cal) throws S
     }
 
     @Override
-    public void updateTimestamp(final String columnName, final java.sql.Timestamp x)
-      throws SQLException {
+    public void updateTimestamp(final String columnName, final java.sql.Timestamp x) throws SQLException {
         checkOpen();
     }
 
