@@ -21,6 +21,7 @@ import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.junit.jupiter.api.Assertions.fail;
 
@@ -33,6 +34,7 @@ import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Statement;
+import java.time.Duration;
 import java.util.HashMap;
 import java.util.Map;
 
@@ -49,6 +51,8 @@ import org.junit.jupiter.api.Test;
  */
 public class TestPerUserPoolDataSource extends TestConnectionPool {
 
+    private static final Duration DURATION_1_MILLISECOND = Duration.ofMillis(1);
+
     private String user;
 
     private DataSource ds;
@@ -71,11 +75,10 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         final PerUserPoolDataSource tds = new PerUserPoolDataSource();
         tds.setConnectionPoolDataSource(pcds);
         tds.setDefaultMaxTotal(getMaxTotal());
-        tds.setDefaultMaxWaitMillis((int)getMaxWaitMillis());
+        tds.setDefaultMaxWait(getMaxWaitDuration());
         tds.setPerUserMaxTotal(user, getMaxTotal());
-        tds.setPerUserMaxWaitMillis(user, getMaxWaitMillis());
-        tds.setDefaultTransactionIsolation(
-            Connection.TRANSACTION_READ_COMMITTED);
+        tds.setPerUserMaxWait(user, getMaxWaitDuration());
+        tds.setDefaultTransactionIsolation(Connection.TRANSACTION_READ_COMMITTED);
         tds.setDefaultAutoCommit(Boolean.TRUE);
         ds = tds;
     }
@@ -90,10 +93,7 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
     // See DBCP-8
     @Test
     public void testChangePassword() throws Exception {
-        try (Connection c = ds.getConnection(user, "bay")){
-            fail("Should have generated SQLException");
-        } catch (final SQLException expected) {
-        }
+        assertThrows(SQLException.class, () -> ds.getConnection(user, "bay"));
         final Connection con1 = ds.getConnection(user, "bar");
         final Connection con2 = ds.getConnection(user, "bar");
         final Connection con3 = ds.getConnection(user, "bar");
@@ -221,20 +221,63 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         }
     }
 
+    @SuppressWarnings("deprecation")
+    @Test
+    public void testDepreactedAccessors() {
+        try (final PerUserPoolDataSource ds = new PerUserPoolDataSource()) {
+            int i = 0;
+            //
+            i++;
+            ds.setDefaultMaxWaitMillis(i);
+            assertEquals(i, ds.getDefaultMaxWaitMillis());
+            assertEquals(Duration.ofMillis(i), ds.getDefaultMaxWait());
+            //
+            i++;
+            ds.setDefaultMinEvictableIdleTimeMillis(i);
+            assertEquals(i, ds.getDefaultMinEvictableIdleTimeMillis());
+            assertEquals(Duration.ofMillis(i), ds.getDefaultMinEvictableIdleDuration());
+            //
+            i++;
+            ds.setDefaultSoftMinEvictableIdleTimeMillis(i);
+            assertEquals(i, ds.getDefaultSoftMinEvictableIdleTimeMillis());
+            assertEquals(Duration.ofMillis(i), ds.getDefaultSoftMinEvictableIdleDuration());
+            //
+            i++;
+            ds.setDefaultTimeBetweenEvictionRunsMillis(i);
+            assertEquals(i, ds.getDefaultTimeBetweenEvictionRunsMillis());
+            assertEquals(Duration.ofMillis(i), ds.getDefaultDurationBetweenEvictionRuns());
+            //
+            i++;
+            ds.setPerUserMaxWaitMillis(user, Long.valueOf(i));
+            assertEquals(i, ds.getPerUserMaxWaitMillis(user));
+            assertEquals(Duration.ofMillis(i), ds.getPerUserMaxWaitDuration(user));
+            //
+            i++;
+            ds.setPerUserMinEvictableIdleTimeMillis(user, Long.valueOf(i));
+            assertEquals(i, ds.getPerUserMinEvictableIdleTimeMillis(user));
+            assertEquals(Duration.ofMillis(i), ds.getPerUserMinEvictableIdleDuration(user));
+            //
+            i++;
+            ds.setPerUserSoftMinEvictableIdleTimeMillis(user, Long.valueOf(i));
+            assertEquals(i, ds.getPerUserSoftMinEvictableIdleTimeMillis(user));
+            assertEquals(Duration.ofMillis(i), ds.getPerUserSoftMinEvictableIdleDuration(user));
+            //
+            i++;
+            ds.setPerUserTimeBetweenEvictionRunsMillis(user, Long.valueOf(i));
+            assertEquals(i, ds.getPerUserTimeBetweenEvictionRunsMillis(user));
+            assertEquals(Duration.ofMillis(i), ds.getPerUserDurationBetweenEvictionRuns(user));
+        }
+    }
+
     /**
      * Switching 'u1 to 'u2' and 'p1' to 'p2' will
      * exhibit the bug detailed in
      * https://issues.apache.org/bugzilla/show_bug.cgi?id=18905
      */
     @Test
-    public void testIncorrectPassword() throws Exception {
+    public void testIncorrectPassword() throws SQLException {
         // Use bad password
-        try (Connection c = ds.getConnection("u1", "zlsafjk")){
-            fail("Able to retrieve connection with incorrect password");
-        } catch (final SQLException e1) {
-            // should fail
-
-        }
+        assertThrows(SQLException.class, () -> ds.getConnection("u1", "zlsafjk"));
 
         // Use good password
         ds.getConnection("u1", "p1").close();
@@ -252,28 +295,22 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
 
         // Try related users and passwords
         ds.getConnection(user, "bar").close();
-        try (Connection c = ds.getConnection("foob", "ar")) {
-            fail("Should have caused an SQLException");
-        } catch (final SQLException expected) {
-        }
-        try (Connection c = ds.getConnection(user, "baz")){
-            fail("Should have generated SQLException");
-        } catch (final SQLException expected) {
-        }
+        assertThrows(SQLException.class, () -> ds.getConnection("foob", "ar"));
+        assertThrows(SQLException.class, () -> ds.getConnection(user, "baz"));
     }
 
     @Override
     @Test
     public void testMaxTotal() throws Exception {
         final Connection[] c = new Connection[getMaxTotal()];
-        for (int i=0; i<c.length; i++) {
+        for (int i = 0; i < c.length; i++) {
             c[i] = ds.getConnection();
             assertNotNull(c[i]);
         }
 
-        try (Connection conn = ds.getConnection()){
+        try (Connection conn = ds.getConnection()) {
             fail("Allowed to open more than DefaultMaxTotal connections.");
-        } catch(final java.sql.SQLException e) {
+        } catch (final java.sql.SQLException e) {
             // should only be able to open 10 connections, so this test should
             // throw an exception
         }
@@ -290,33 +327,29 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
     @Test
     public void testMaxWaitMillisZero() throws Exception {
         final PerUserPoolDataSource tds = (PerUserPoolDataSource) ds;
-        tds.setDefaultMaxWaitMillis(0);
+        tds.setDefaultMaxWait(Duration.ZERO);
         tds.setPerUserMaxTotal("u1", 1);
-        final Connection conn = tds.getConnection("u1", "p1");
-        try (Connection c2 = tds.getConnection("u1", "p1")){
-            fail("Expecting Pool Exhausted exception");
-        } catch (final SQLException ex) {
-            // expected
+        try (final Connection conn = tds.getConnection("u1", "p1")) {
+            assertThrows(SQLException.class, () -> tds.getConnection("u1", "p1"));
         }
-        conn.close();
     }
 
     @Test
     public void testMultipleThreads1() throws Exception {
         // Override wait time in order to allow for Thread.sleep(1) sometimes taking a lot longer on
         // some JVMs, e.g. Windows.
-        final int defaultMaxWaitMillis = 430;
-        ((PerUserPoolDataSource) ds).setDefaultMaxWaitMillis(defaultMaxWaitMillis);
-        ((PerUserPoolDataSource) ds).setPerUserMaxWaitMillis(user, (long) defaultMaxWaitMillis);
-        multipleThreads(1, false, false, defaultMaxWaitMillis);
+        final Duration defaultMaxWaitDuration = Duration.ofMillis(430);
+        ((PerUserPoolDataSource) ds).setDefaultMaxWait(defaultMaxWaitDuration);
+        ((PerUserPoolDataSource) ds).setPerUserMaxWait(user, defaultMaxWaitDuration);
+        multipleThreads(Duration.ofMillis(1), false, false, defaultMaxWaitDuration);
     }
 
     @Test
     public void testMultipleThreads2() throws Exception {
-        final int defaultMaxWaitMillis = 500;
-        ((PerUserPoolDataSource) ds).setDefaultMaxWaitMillis(defaultMaxWaitMillis);
-        ((PerUserPoolDataSource) ds).setPerUserMaxWaitMillis(user, (long) defaultMaxWaitMillis);
-        multipleThreads(2 * defaultMaxWaitMillis, true, true, defaultMaxWaitMillis);
+        final Duration defaultMaxWaitDuration = Duration.ofMillis(500);
+        ((PerUserPoolDataSource) ds).setDefaultMaxWait(defaultMaxWaitDuration);
+        ((PerUserPoolDataSource) ds).setPerUserMaxWait(user, defaultMaxWaitDuration);
+        multipleThreads(defaultMaxWaitDuration.multipliedBy(2), true, true, defaultMaxWaitDuration);
     }
 
     @Override
@@ -850,41 +883,40 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
     }
 
     @Test
-    public void testPerUserMaxWaitMillisMapInitialized() {
+    public void testPerUserMaxWaitDurationMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
-        Map<String, Long> values = new HashMap<>();
-        values.put("key", 0L);
-        ds.setPerUserMaxWaitMillis(values);
-        assertEquals(0L, ds.getPerUserMaxWaitMillis("key"));
+        Map<String, Duration> values = new HashMap<>();
+        values.put("key", Duration.ZERO);
+        ds.setPerUserMaxWaitDuration(values);
+        assertEquals(Duration.ZERO, ds.getPerUserMaxWaitDuration("key"));
         values = new HashMap<>();
-        values.put("anonymous", 0L);
-        ds.setPerUserMaxWaitMillis(values);
-        assertEquals(ds.getDefaultMaxWaitMillis(), ds.getPerUserMaxWaitMillis("key"));
-        assertEquals(0L, ds.getPerUserMaxWaitMillis("anonymous"));
+        values.put("anonymous", Duration.ZERO);
+        ds.setPerUserMaxWaitDuration(values);
+        assertEquals(ds.getDefaultMaxWait(), ds.getPerUserMaxWaitDuration("key"));
+        assertEquals(Duration.ZERO, ds.getPerUserMaxWaitDuration("anonymous"));
     }
 
-    // -- per user max total
-
     @Test
-    public void testPerUserMaxWaitMillisMapNotInitialized() {
+    public void testPerUserMaxWaitDurationMapNotInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
-        final Map<String, Long> values = new HashMap<>();
-        values.put("key", 1L);
-        ds.setPerUserMaxWaitMillis(values);
-        assertEquals(1L, ds.getPerUserMaxWaitMillis("key"));
+        final Map<String, Duration> values = new HashMap<>();
+        values.put("key", DURATION_1_MILLISECOND);
+        ds.setPerUserMaxWaitDuration(values);
+        assertEquals(DURATION_1_MILLISECOND, ds.getPerUserMaxWaitDuration("key"));
     }
 
     @Test
-    public void testPerUserMaxWaitMillisMapNotInitializedMissingKey() {
+    public void testPerUserMaxWaitDurationMapNotInitializedMissingKey() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
-        final Map<String, Long> values = new HashMap<>();
-        values.put("key", 0L);
-        ds.setPerUserMaxWaitMillis(values);
-        assertEquals(ds.getDefaultMaxWaitMillis(), ds.getPerUserMaxWaitMillis("missingkey"));
+        final Map<String, Duration> values = new HashMap<>();
+        values.put("key", Duration.ZERO);
+        ds.setPerUserMaxWaitDuration(values);
+        assertEquals(ds.getDefaultMaxWait(), ds.getPerUserMaxWaitDuration("missingkey"));
     }
 
     @Test
-    public void testPerUserMaxWaitMillisWithUserMapInitialized() {
+    @SuppressWarnings("deprecation")
+    public void testPerUserMaxWaitMillisWithUserMapInitialized_Deprecated() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
         ds.setPerUserMaxWaitMillis(user, 0L);
         assertEquals(0L, ds.getPerUserMaxWaitMillis(user));
@@ -894,14 +926,16 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
     }
 
     @Test
-    public void testPerUserMaxWaitMillisWithUserMapNotInitialized() {
+    @SuppressWarnings("deprecation")
+    public void testPerUserMaxWaitMillisWithUserMapNotInitialized_Deprecated() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
         ds.setPerUserMaxWaitMillis(user, 0L);
         assertEquals(0L, ds.getPerUserMaxWaitMillis(user));
     }
 
     @Test
-    public void testPerUserMaxWaitMillisWithUserMapNotInitializedMissingKey() {
+    @SuppressWarnings("deprecation")
+    public void testPerUserMaxWaitMillisWithUserMapNotInitializedMissingKey_Deprecated() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
         ds.setPerUserMaxWaitMillis("whatismyuseragain?", 0L);
         assertEquals(ds.getDefaultMaxWaitMillis(), ds.getPerUserMaxWaitMillis("missingkey"));
@@ -922,16 +956,15 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(0, tds.getNumIdle("u1"));
         assertEquals(0, tds.getNumIdle("u2"));
 
-        Connection conn = tds.getConnection();
-        assertNotNull(conn);
-        assertEquals(1, tds.getNumActive());
-        assertEquals(0, tds.getNumActive("u1"));
-        assertEquals(0, tds.getNumActive("u2"));
-        assertEquals(0, tds.getNumIdle());
-        assertEquals(0, tds.getNumIdle("u1"));
-        assertEquals(0, tds.getNumIdle("u2"));
-
-        conn.close();
+        try (Connection conn = tds.getConnection()) {
+            assertNotNull(conn);
+            assertEquals(1, tds.getNumActive());
+            assertEquals(0, tds.getNumActive("u1"));
+            assertEquals(0, tds.getNumActive("u2"));
+            assertEquals(0, tds.getNumIdle());
+            assertEquals(0, tds.getNumIdle("u1"));
+            assertEquals(0, tds.getNumIdle("u2"));
+        }
         assertEquals(0, tds.getNumActive());
         assertEquals(0, tds.getNumActive("u1"));
         assertEquals(0, tds.getNumActive("u2"));
@@ -939,16 +972,16 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(0, tds.getNumIdle("u1"));
         assertEquals(0, tds.getNumIdle("u2"));
 
-        conn = tds.getConnection("u1", "p1");
-        assertNotNull(conn);
-        assertEquals(0, tds.getNumActive());
-        assertEquals(1, tds.getNumActive("u1"));
-        assertEquals(0, tds.getNumActive("u2"));
-        assertEquals(1, tds.getNumIdle());
-        assertEquals(0, tds.getNumIdle("u1"));
-        assertEquals(0, tds.getNumIdle("u2"));
+        try (Connection conn = tds.getConnection("u1", "p1")) {
+            assertNotNull(conn);
+            assertEquals(0, tds.getNumActive());
+            assertEquals(1, tds.getNumActive("u1"));
+            assertEquals(0, tds.getNumActive("u2"));
+            assertEquals(1, tds.getNumIdle());
+            assertEquals(0, tds.getNumIdle("u1"));
+            assertEquals(0, tds.getNumIdle("u2"));
+        }
 
-        conn.close();
         assertEquals(0, tds.getNumActive());
         assertEquals(0, tds.getNumActive("u1"));
         assertEquals(0, tds.getNumActive("u2"));
@@ -960,35 +993,40 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
     // -- per user max wait millis
 
     @Test
-    public void testPerUserMinEvictableIdleTimeMillisMapInitialized() {
+    public void testPerUserMinEvictableIdleDurationMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
-        Map<String, Long> values = new HashMap<>();
-        values.put("key", 0L);
-        ds.setPerUserMinEvictableIdleTimeMillis(values);
+        Map<String, Duration> values = new HashMap<>();
+        values.put("key", Duration.ZERO);
+        ds.setPerUserMinEvictableIdle(values);
         assertEquals(0L, ds.getPerUserMinEvictableIdleTimeMillis("key"));
+        assertEquals(Duration.ZERO, ds.getPerUserMinEvictableIdleDuration("key"));
         values = new HashMap<>();
-        values.put("anonymous", 0L);
-        ds.setPerUserMinEvictableIdleTimeMillis(values);
+        values.put("anonymous", Duration.ZERO);
+        ds.setPerUserMinEvictableIdle(values);
         assertEquals(ds.getDefaultMinEvictableIdleTimeMillis(), ds.getPerUserMinEvictableIdleTimeMillis("key"));
+        assertEquals(ds.getDefaultMinEvictableIdleDuration(), ds.getPerUserMinEvictableIdleDuration("key"));
         assertEquals(0L, ds.getPerUserMinEvictableIdleTimeMillis("anonymous"));
+        assertEquals(Duration.ZERO, ds.getPerUserMinEvictableIdleDuration("anonymous"));
     }
 
     @Test
-    public void testPerUserMinEvictableIdleTimeMillisMapNotInitialized() {
+    public void testPerUserMinEvictableIdleDurationMapNotInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
-        final Map<String, Long> values = new HashMap<>();
-        values.put("key", 1L);
-        ds.setPerUserMinEvictableIdleTimeMillis(values);
+        final Map<String, Duration> values = new HashMap<>();
+        values.put("key", DURATION_1_MILLISECOND);
+        ds.setPerUserMinEvictableIdle(values);
         assertEquals(1L, ds.getPerUserMinEvictableIdleTimeMillis("key"));
+        assertEquals(DURATION_1_MILLISECOND, ds.getPerUserMinEvictableIdleDuration("key"));
     }
 
     @Test
-    public void testPerUserMinEvictableIdleTimeMillisMapNotInitializedMissingKey() {
+    public void testPerUserMinEvictableIdleDurationMapNotInitializedMissingKey() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
-        final Map<String, Long> values = new HashMap<>();
-        values.put("key", 0L);
-        ds.setPerUserMinEvictableIdleTimeMillis(values);
+        final Map<String, Duration> values = new HashMap<>();
+        values.put("key", Duration.ZERO);
+        ds.setPerUserMinEvictableIdle(values);
         assertEquals(ds.getDefaultMinEvictableIdleTimeMillis(), ds.getPerUserMinEvictableIdleTimeMillis("missingkey"));
+        assertEquals(ds.getDefaultMinEvictableIdleDuration(), ds.getPerUserMinEvictableIdleDuration("missingkey"));
     }
 
     @Test
@@ -1134,35 +1172,40 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
     // -- per user num tests per eviction run
 
     @Test
-    public void testPerUserSoftMinEvictableIdleTimeMillisMapInitialized() {
+    public void testPerUserSoftMinEvictableIdleDurationMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
-        Map<String, Long> values = new HashMap<>();
-        values.put("key", 0L);
-        ds.setPerUserSoftMinEvictableIdleTimeMillis(values);
+        Map<String, Duration> values = new HashMap<>();
+        values.put("key", Duration.ZERO);
+        ds.setPerUserSoftMinEvictableIdle(values);
         assertEquals(0L, ds.getPerUserSoftMinEvictableIdleTimeMillis("key"));
+        assertEquals(Duration.ZERO, ds.getPerUserSoftMinEvictableIdleDuration("key"));
         values = new HashMap<>();
-        values.put("anonymous", 0L);
-        ds.setPerUserSoftMinEvictableIdleTimeMillis(values);
+        values.put("anonymous", Duration.ZERO);
+        ds.setPerUserSoftMinEvictableIdle(values);
         assertEquals(ds.getDefaultSoftMinEvictableIdleTimeMillis(), ds.getPerUserSoftMinEvictableIdleTimeMillis("key"));
+        assertEquals(ds.getDefaultSoftMinEvictableIdleDuration(), ds.getPerUserSoftMinEvictableIdleDuration("key"));
         assertEquals(0L, ds.getPerUserSoftMinEvictableIdleTimeMillis("anonymous"));
+        assertEquals(Duration.ZERO, ds.getPerUserSoftMinEvictableIdleDuration("anonymous"));
     }
 
     @Test
-    public void testPerUserSoftMinEvictableIdleTimeMillisMapNotInitialized() {
+    public void testPerUserSoftMinEvictableIdleDurationMapNotInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
-        final Map<String, Long> values = new HashMap<>();
-        values.put("key", 1L);
-        ds.setPerUserSoftMinEvictableIdleTimeMillis(values);
+        final Map<String, Duration> values = new HashMap<>();
+        values.put("key", DURATION_1_MILLISECOND);
+        ds.setPerUserSoftMinEvictableIdle(values);
         assertEquals(1L, ds.getPerUserSoftMinEvictableIdleTimeMillis("key"));
+        assertEquals(DURATION_1_MILLISECOND, ds.getPerUserSoftMinEvictableIdleDuration("key"));
     }
 
     @Test
-    public void testPerUserSoftMinEvictableIdleTimeMillisMapNotInitializedMissingKey() {
+    public void testPerUserSoftMinEvictableIdleDurationMapNotInitializedMissingKey() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
-        final Map<String, Long> values = new HashMap<>();
-        values.put("key", 0L);
-        ds.setPerUserSoftMinEvictableIdleTimeMillis(values);
+        final Map<String, Duration> values = new HashMap<>();
+        values.put("key", Duration.ZERO);
+        ds.setPerUserSoftMinEvictableIdle(values);
         assertEquals(ds.getDefaultSoftMinEvictableIdleTimeMillis(), ds.getPerUserSoftMinEvictableIdleTimeMillis("missingkey"));
+        assertEquals(ds.getDefaultSoftMinEvictableIdleDuration(), ds.getPerUserSoftMinEvictableIdleDuration("missingkey"));
     }
 
     @Test
@@ -1421,38 +1464,41 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(ds.getDefaultTestWhileIdle(), ds.getPerUserTestWhileIdle("missingkey"));
     }
 
-    // -- per user test while idle
-
     @Test
-    public void testPerUserTimeBetweenEvictionRunsMillisMapInitialized() {
+    public void testPerUserDurationBetweenEvictionRunsMapInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
-        Map<String, Long> values = new HashMap<>();
-        values.put("key", 0L);
-        ds.setPerUserTimeBetweenEvictionRunsMillis(values);
+        Map<String, Duration> values = new HashMap<>();
+        values.put("key", Duration.ZERO);
+        ds.setPerUserDurationBetweenEvictionRuns(values);
         assertEquals(0L, ds.getPerUserTimeBetweenEvictionRunsMillis("key"));
+        assertEquals(Duration.ZERO, ds.getPerUserDurationBetweenEvictionRuns("key"));
         values = new HashMap<>();
-        values.put("anonymous", 0L);
-        ds.setPerUserTimeBetweenEvictionRunsMillis(values);
+        values.put("anonymous", Duration.ZERO);
+        ds.setPerUserDurationBetweenEvictionRuns(values);
         assertEquals(ds.getDefaultTimeBetweenEvictionRunsMillis(), ds.getPerUserTimeBetweenEvictionRunsMillis("key"));
+        assertEquals(ds.getDefaultDurationBetweenEvictionRuns(), ds.getPerUserDurationBetweenEvictionRuns("key"));
         assertEquals(0L, ds.getPerUserTimeBetweenEvictionRunsMillis("anonymous"));
+        assertEquals(Duration.ZERO, ds.getPerUserDurationBetweenEvictionRuns("anonymous"));
     }
 
     @Test
-    public void testPerUserTimeBetweenEvictionRunsMillisMapNotInitialized() {
+    public void testPerUserDurationBetweenEvictionRunsMapNotInitialized() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
-        final Map<String, Long> values = new HashMap<>();
-        values.put("key", 1L);
-        ds.setPerUserTimeBetweenEvictionRunsMillis(values);
+        final Map<String, Duration> values = new HashMap<>();
+        values.put("key", DURATION_1_MILLISECOND);
+        ds.setPerUserDurationBetweenEvictionRuns(values);
         assertEquals(1L, ds.getPerUserTimeBetweenEvictionRunsMillis("key"));
+        assertEquals(DURATION_1_MILLISECOND, ds.getPerUserDurationBetweenEvictionRuns("key"));
     }
 
     @Test
-    public void testPerUserTimeBetweenEvictionRunsMillisMapNotInitializedMissingKey() {
+    public void testPerUserDurationBetweenEvictionRunsMapNotInitializedMissingKey() {
         final PerUserPoolDataSource ds = (PerUserPoolDataSource) this.ds;
-        final Map<String, Long> values = new HashMap<>();
-        values.put("key", 0L);
-        ds.setPerUserTimeBetweenEvictionRunsMillis(values);
+        final Map<String, Duration> values = new HashMap<>();
+        values.put("key", Duration.ZERO);
+        ds.setPerUserDurationBetweenEvictionRuns(values);
         assertEquals(ds.getDefaultTimeBetweenEvictionRunsMillis(), ds.getPerUserTimeBetweenEvictionRunsMillis("missingkey"));
+        assertEquals(ds.getDefaultDurationBetweenEvictionRuns(), ds.getPerUserDurationBetweenEvictionRuns("missingkey"));
     }
 
     @Test
@@ -1499,35 +1545,31 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         final Object obj = in.readObject();
         in.close();
 
-        assertEquals( 1, ((PerUserPoolDataSource)obj).getNumIdle() );
+        assertEquals(1, ((PerUserPoolDataSource) obj).getNumIdle());
     }
 
     @Override
     @Test
-    public void testSimple() throws Exception
-    {
-        final Connection conn = ds.getConnection();
-        assertNotNull(conn);
-        final PreparedStatement stmt = conn.prepareStatement("select * from dual");
-        assertNotNull(stmt);
-        final ResultSet rset = stmt.executeQuery();
-        assertNotNull(rset);
-        assertTrue(rset.next());
-        rset.close();
-        stmt.close();
-        conn.close();
+    public void testSimple() throws Exception {
+        try (final Connection conn = ds.getConnection()) {
+            assertNotNull(conn);
+            try (final PreparedStatement stmt = conn.prepareStatement("select * from dual")) {
+                assertNotNull(stmt);
+                try (final ResultSet rset = stmt.executeQuery()) {
+                    assertNotNull(rset);
+                    assertTrue(rset.next());
+                }
+            }
+        }
     }
 
     @Override
     @Test
-    public void testSimple2()
-        throws Exception
-    {
+    public void testSimple2() throws Exception {
         Connection conn = ds.getConnection();
         assertNotNull(conn);
 
-        PreparedStatement stmt =
-            conn.prepareStatement("select * from dual");
+        PreparedStatement stmt = conn.prepareStatement("select * from dual");
         assertNotNull(stmt);
         ResultSet rset = stmt.executeQuery();
         assertNotNull(rset);
@@ -1544,9 +1586,9 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         stmt.close();
 
         conn.close();
-        try (Statement s = conn.createStatement()){
+        try (Statement s = conn.createStatement()) {
             fail("Can't use closed connections");
-        } catch(final SQLException e) {
+        } catch (final SQLException e) {
             // expected
         }
 
@@ -1574,36 +1616,32 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
     }
 
     @Test
-    public void testSimpleWithUsername() throws Exception
-    {
-        final Connection conn = ds.getConnection("u1", "p1");
-        assertNotNull(conn);
-        final PreparedStatement stmt = conn.prepareStatement("select * from dual");
-        assertNotNull(stmt);
-        final ResultSet rset = stmt.executeQuery();
-        assertNotNull(rset);
-        assertTrue(rset.next());
-        rset.close();
-        stmt.close();
-        conn.close();
+    public void testSimpleWithUsername() throws Exception {
+        try (final Connection conn = ds.getConnection("u1", "p1")) {
+            assertNotNull(conn);
+            try (final PreparedStatement stmt = conn.prepareStatement("select * from dual")) {
+                assertNotNull(stmt);
+                try (final ResultSet rset = stmt.executeQuery()) {
+                    assertNotNull(rset);
+                    assertTrue(rset.next());
+                }
+            }
+        }
     }
 
     @Test
     public void testTransactionIsolationBehavior() throws Exception {
-        final Connection conn = getConnection();
-        assertNotNull(conn);
-        assertEquals(Connection.TRANSACTION_READ_COMMITTED,
-                     conn.getTransactionIsolation());
-        conn.setTransactionIsolation(Connection.TRANSACTION_READ_UNCOMMITTED);
-        conn.close();
+        try (Connection conn = getConnection()) {
+            assertNotNull(conn);
+            assertEquals(Connection.TRANSACTION_READ_COMMITTED, conn.getTransactionIsolation());
+            conn.setTransactionIsolation(Connection.TRANSACTION_READ_UNCOMMITTED);
+        }
 
         final Connection conn2 = getConnection();
-        assertEquals(Connection.TRANSACTION_READ_COMMITTED,
-                     conn2.getTransactionIsolation());
+        assertEquals(Connection.TRANSACTION_READ_COMMITTED, conn2.getTransactionIsolation());
 
         final Connection conn3 = getConnection();
-        assertEquals(Connection.TRANSACTION_READ_COMMITTED,
-                     conn3.getTransactionIsolation());
+        assertEquals(Connection.TRANSACTION_READ_COMMITTED, conn3.getTransactionIsolation());
         conn2.close();
         conn3.close();
     }
@@ -1617,23 +1655,21 @@ public class TestPerUserPoolDataSource extends TestConnectionPool {
         assertEquals(0, tds.getNumActive());
         assertEquals(0, tds.getNumIdle());
 
-        Connection conn = tds.getConnection();
-        assertNotNull(conn);
-        assertEquals(1, tds.getNumActive());
-        assertEquals(0, tds.getNumIdle());
-
-        conn.close();
+        try (Connection conn = tds.getConnection()) {
+            assertNotNull(conn);
+            assertEquals(1, tds.getNumActive());
+            assertEquals(0, tds.getNumIdle());
+        }
         assertEquals(0, tds.getNumActive());
         assertEquals(1, tds.getNumIdle());
 
-        conn = tds.getConnection("u1", "p1");
-        assertNotNull(conn);
-        assertEquals(0, tds.getNumActive());
-        assertEquals(1, tds.getNumIdle());
-        assertEquals(1, tds.getNumActive("u1"));
-        assertEquals(0, tds.getNumIdle("u1"));
-
-        conn.close();
+        try (Connection conn = tds.getConnection("u1", "p1")) {
+            assertNotNull(conn);
+            assertEquals(0, tds.getNumActive());
+            assertEquals(1, tds.getNumIdle());
+            assertEquals(1, tds.getNumActive("u1"));
+            assertEquals(0, tds.getNumIdle("u1"));
+        }
         assertEquals(0, tds.getNumActive());
         assertEquals(1, tds.getNumIdle());
         assertEquals(0, tds.getNumActive("u1"));
